# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class JobExecutionSummary(object):
    """
    A summary of a job execution on a Managed Database.
    """

    #: A constant which can be used with the database_type property of a JobExecutionSummary.
    #: This constant has a value of "EXTERNAL_SIDB"
    DATABASE_TYPE_EXTERNAL_SIDB = "EXTERNAL_SIDB"

    #: A constant which can be used with the database_type property of a JobExecutionSummary.
    #: This constant has a value of "EXTERNAL_RAC"
    DATABASE_TYPE_EXTERNAL_RAC = "EXTERNAL_RAC"

    #: A constant which can be used with the database_type property of a JobExecutionSummary.
    #: This constant has a value of "CLOUD_SIDB"
    DATABASE_TYPE_CLOUD_SIDB = "CLOUD_SIDB"

    #: A constant which can be used with the database_type property of a JobExecutionSummary.
    #: This constant has a value of "CLOUD_RAC"
    DATABASE_TYPE_CLOUD_RAC = "CLOUD_RAC"

    #: A constant which can be used with the database_type property of a JobExecutionSummary.
    #: This constant has a value of "SHARED"
    DATABASE_TYPE_SHARED = "SHARED"

    #: A constant which can be used with the database_type property of a JobExecutionSummary.
    #: This constant has a value of "DEDICATED"
    DATABASE_TYPE_DEDICATED = "DEDICATED"

    #: A constant which can be used with the database_sub_type property of a JobExecutionSummary.
    #: This constant has a value of "CDB"
    DATABASE_SUB_TYPE_CDB = "CDB"

    #: A constant which can be used with the database_sub_type property of a JobExecutionSummary.
    #: This constant has a value of "PDB"
    DATABASE_SUB_TYPE_PDB = "PDB"

    #: A constant which can be used with the database_sub_type property of a JobExecutionSummary.
    #: This constant has a value of "NON_CDB"
    DATABASE_SUB_TYPE_NON_CDB = "NON_CDB"

    #: A constant which can be used with the database_sub_type property of a JobExecutionSummary.
    #: This constant has a value of "ACD"
    DATABASE_SUB_TYPE_ACD = "ACD"

    #: A constant which can be used with the database_sub_type property of a JobExecutionSummary.
    #: This constant has a value of "ADB"
    DATABASE_SUB_TYPE_ADB = "ADB"

    #: A constant which can be used with the deployment_type property of a JobExecutionSummary.
    #: This constant has a value of "ONPREMISE"
    DEPLOYMENT_TYPE_ONPREMISE = "ONPREMISE"

    #: A constant which can be used with the deployment_type property of a JobExecutionSummary.
    #: This constant has a value of "BM"
    DEPLOYMENT_TYPE_BM = "BM"

    #: A constant which can be used with the deployment_type property of a JobExecutionSummary.
    #: This constant has a value of "VM"
    DEPLOYMENT_TYPE_VM = "VM"

    #: A constant which can be used with the deployment_type property of a JobExecutionSummary.
    #: This constant has a value of "EXADATA"
    DEPLOYMENT_TYPE_EXADATA = "EXADATA"

    #: A constant which can be used with the deployment_type property of a JobExecutionSummary.
    #: This constant has a value of "EXADATA_CC"
    DEPLOYMENT_TYPE_EXADATA_CC = "EXADATA_CC"

    #: A constant which can be used with the deployment_type property of a JobExecutionSummary.
    #: This constant has a value of "AUTONOMOUS"
    DEPLOYMENT_TYPE_AUTONOMOUS = "AUTONOMOUS"

    #: A constant which can be used with the workload_type property of a JobExecutionSummary.
    #: This constant has a value of "OLTP"
    WORKLOAD_TYPE_OLTP = "OLTP"

    #: A constant which can be used with the workload_type property of a JobExecutionSummary.
    #: This constant has a value of "DW"
    WORKLOAD_TYPE_DW = "DW"

    #: A constant which can be used with the workload_type property of a JobExecutionSummary.
    #: This constant has a value of "AJD"
    WORKLOAD_TYPE_AJD = "AJD"

    #: A constant which can be used with the workload_type property of a JobExecutionSummary.
    #: This constant has a value of "APEX"
    WORKLOAD_TYPE_APEX = "APEX"

    def __init__(self, **kwargs):
        """
        Initializes a new JobExecutionSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this JobExecutionSummary.
        :type id: str

        :param name:
            The value to assign to the name property of this JobExecutionSummary.
        :type name: str

        :param compartment_id:
            The value to assign to the compartment_id property of this JobExecutionSummary.
        :type compartment_id: str

        :param managed_database_group_id:
            The value to assign to the managed_database_group_id property of this JobExecutionSummary.
        :type managed_database_group_id: str

        :param managed_database_id:
            The value to assign to the managed_database_id property of this JobExecutionSummary.
        :type managed_database_id: str

        :param managed_database_name:
            The value to assign to the managed_database_name property of this JobExecutionSummary.
        :type managed_database_name: str

        :param database_type:
            The value to assign to the database_type property of this JobExecutionSummary.
            Allowed values for this property are: "EXTERNAL_SIDB", "EXTERNAL_RAC", "CLOUD_SIDB", "CLOUD_RAC", "SHARED", "DEDICATED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type database_type: str

        :param database_sub_type:
            The value to assign to the database_sub_type property of this JobExecutionSummary.
            Allowed values for this property are: "CDB", "PDB", "NON_CDB", "ACD", "ADB", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type database_sub_type: str

        :param deployment_type:
            The value to assign to the deployment_type property of this JobExecutionSummary.
            Allowed values for this property are: "ONPREMISE", "BM", "VM", "EXADATA", "EXADATA_CC", "AUTONOMOUS", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type deployment_type: str

        :param is_cluster:
            The value to assign to the is_cluster property of this JobExecutionSummary.
        :type is_cluster: bool

        :param workload_type:
            The value to assign to the workload_type property of this JobExecutionSummary.
            Allowed values for this property are: "OLTP", "DW", "AJD", "APEX", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type workload_type: str

        :param job_id:
            The value to assign to the job_id property of this JobExecutionSummary.
        :type job_id: str

        :param job_name:
            The value to assign to the job_name property of this JobExecutionSummary.
        :type job_name: str

        :param status:
            The value to assign to the status property of this JobExecutionSummary.
        :type status: str

        :param time_created:
            The value to assign to the time_created property of this JobExecutionSummary.
        :type time_created: datetime

        :param time_completed:
            The value to assign to the time_completed property of this JobExecutionSummary.
        :type time_completed: datetime

        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'compartment_id': 'str',
            'managed_database_group_id': 'str',
            'managed_database_id': 'str',
            'managed_database_name': 'str',
            'database_type': 'str',
            'database_sub_type': 'str',
            'deployment_type': 'str',
            'is_cluster': 'bool',
            'workload_type': 'str',
            'job_id': 'str',
            'job_name': 'str',
            'status': 'str',
            'time_created': 'datetime',
            'time_completed': 'datetime'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'compartment_id': 'compartmentId',
            'managed_database_group_id': 'managedDatabaseGroupId',
            'managed_database_id': 'managedDatabaseId',
            'managed_database_name': 'managedDatabaseName',
            'database_type': 'databaseType',
            'database_sub_type': 'databaseSubType',
            'deployment_type': 'deploymentType',
            'is_cluster': 'isCluster',
            'workload_type': 'workloadType',
            'job_id': 'jobId',
            'job_name': 'jobName',
            'status': 'status',
            'time_created': 'timeCreated',
            'time_completed': 'timeCompleted'
        }

        self._id = None
        self._name = None
        self._compartment_id = None
        self._managed_database_group_id = None
        self._managed_database_id = None
        self._managed_database_name = None
        self._database_type = None
        self._database_sub_type = None
        self._deployment_type = None
        self._is_cluster = None
        self._workload_type = None
        self._job_id = None
        self._job_name = None
        self._status = None
        self._time_created = None
        self._time_completed = None

    @property
    def id(self):
        """
        **[Required]** Gets the id of this JobExecutionSummary.
        The identifier of the job execution.


        :return: The id of this JobExecutionSummary.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this JobExecutionSummary.
        The identifier of the job execution.


        :param id: The id of this JobExecutionSummary.
        :type: str
        """
        self._id = id

    @property
    def name(self):
        """
        **[Required]** Gets the name of this JobExecutionSummary.
        The name of the job execution.


        :return: The name of this JobExecutionSummary.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this JobExecutionSummary.
        The name of the job execution.


        :param name: The name of this JobExecutionSummary.
        :type: str
        """
        self._name = name

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this JobExecutionSummary.
        The `OCID`__ of the compartment in which the parent job resides.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The compartment_id of this JobExecutionSummary.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this JobExecutionSummary.
        The `OCID`__ of the compartment in which the parent job resides.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param compartment_id: The compartment_id of this JobExecutionSummary.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def managed_database_group_id(self):
        """
        Gets the managed_database_group_id of this JobExecutionSummary.
        The `OCID`__ of the Managed Database Group where the parent job has to be executed.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The managed_database_group_id of this JobExecutionSummary.
        :rtype: str
        """
        return self._managed_database_group_id

    @managed_database_group_id.setter
    def managed_database_group_id(self, managed_database_group_id):
        """
        Sets the managed_database_group_id of this JobExecutionSummary.
        The `OCID`__ of the Managed Database Group where the parent job has to be executed.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param managed_database_group_id: The managed_database_group_id of this JobExecutionSummary.
        :type: str
        """
        self._managed_database_group_id = managed_database_group_id

    @property
    def managed_database_id(self):
        """
        **[Required]** Gets the managed_database_id of this JobExecutionSummary.
        The `OCID`__ of Managed Database associated with the job execution.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The managed_database_id of this JobExecutionSummary.
        :rtype: str
        """
        return self._managed_database_id

    @managed_database_id.setter
    def managed_database_id(self, managed_database_id):
        """
        Sets the managed_database_id of this JobExecutionSummary.
        The `OCID`__ of Managed Database associated with the job execution.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param managed_database_id: The managed_database_id of this JobExecutionSummary.
        :type: str
        """
        self._managed_database_id = managed_database_id

    @property
    def managed_database_name(self):
        """
        **[Required]** Gets the managed_database_name of this JobExecutionSummary.
        The name of the Managed Database associated with the job execution.


        :return: The managed_database_name of this JobExecutionSummary.
        :rtype: str
        """
        return self._managed_database_name

    @managed_database_name.setter
    def managed_database_name(self, managed_database_name):
        """
        Sets the managed_database_name of this JobExecutionSummary.
        The name of the Managed Database associated with the job execution.


        :param managed_database_name: The managed_database_name of this JobExecutionSummary.
        :type: str
        """
        self._managed_database_name = managed_database_name

    @property
    def database_type(self):
        """
        Gets the database_type of this JobExecutionSummary.
        The type of Oracle Database installation.

        Allowed values for this property are: "EXTERNAL_SIDB", "EXTERNAL_RAC", "CLOUD_SIDB", "CLOUD_RAC", "SHARED", "DEDICATED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The database_type of this JobExecutionSummary.
        :rtype: str
        """
        return self._database_type

    @database_type.setter
    def database_type(self, database_type):
        """
        Sets the database_type of this JobExecutionSummary.
        The type of Oracle Database installation.


        :param database_type: The database_type of this JobExecutionSummary.
        :type: str
        """
        allowed_values = ["EXTERNAL_SIDB", "EXTERNAL_RAC", "CLOUD_SIDB", "CLOUD_RAC", "SHARED", "DEDICATED"]
        if not value_allowed_none_or_none_sentinel(database_type, allowed_values):
            database_type = 'UNKNOWN_ENUM_VALUE'
        self._database_type = database_type

    @property
    def database_sub_type(self):
        """
        Gets the database_sub_type of this JobExecutionSummary.
        The subtype of the Oracle Database. Indicates whether the database is a Container Database, Pluggable Database, or a Non-container Database.

        Allowed values for this property are: "CDB", "PDB", "NON_CDB", "ACD", "ADB", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The database_sub_type of this JobExecutionSummary.
        :rtype: str
        """
        return self._database_sub_type

    @database_sub_type.setter
    def database_sub_type(self, database_sub_type):
        """
        Sets the database_sub_type of this JobExecutionSummary.
        The subtype of the Oracle Database. Indicates whether the database is a Container Database, Pluggable Database, or a Non-container Database.


        :param database_sub_type: The database_sub_type of this JobExecutionSummary.
        :type: str
        """
        allowed_values = ["CDB", "PDB", "NON_CDB", "ACD", "ADB"]
        if not value_allowed_none_or_none_sentinel(database_sub_type, allowed_values):
            database_sub_type = 'UNKNOWN_ENUM_VALUE'
        self._database_sub_type = database_sub_type

    @property
    def deployment_type(self):
        """
        Gets the deployment_type of this JobExecutionSummary.
        A list of the supported infrastructure that can be used to deploy the database.

        Allowed values for this property are: "ONPREMISE", "BM", "VM", "EXADATA", "EXADATA_CC", "AUTONOMOUS", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The deployment_type of this JobExecutionSummary.
        :rtype: str
        """
        return self._deployment_type

    @deployment_type.setter
    def deployment_type(self, deployment_type):
        """
        Sets the deployment_type of this JobExecutionSummary.
        A list of the supported infrastructure that can be used to deploy the database.


        :param deployment_type: The deployment_type of this JobExecutionSummary.
        :type: str
        """
        allowed_values = ["ONPREMISE", "BM", "VM", "EXADATA", "EXADATA_CC", "AUTONOMOUS"]
        if not value_allowed_none_or_none_sentinel(deployment_type, allowed_values):
            deployment_type = 'UNKNOWN_ENUM_VALUE'
        self._deployment_type = deployment_type

    @property
    def is_cluster(self):
        """
        Gets the is_cluster of this JobExecutionSummary.
        Indicates whether the Oracle Database is part of a cluster.


        :return: The is_cluster of this JobExecutionSummary.
        :rtype: bool
        """
        return self._is_cluster

    @is_cluster.setter
    def is_cluster(self, is_cluster):
        """
        Sets the is_cluster of this JobExecutionSummary.
        Indicates whether the Oracle Database is part of a cluster.


        :param is_cluster: The is_cluster of this JobExecutionSummary.
        :type: bool
        """
        self._is_cluster = is_cluster

    @property
    def workload_type(self):
        """
        Gets the workload_type of this JobExecutionSummary.
        The workload type of the Autonomous Database.

        Allowed values for this property are: "OLTP", "DW", "AJD", "APEX", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The workload_type of this JobExecutionSummary.
        :rtype: str
        """
        return self._workload_type

    @workload_type.setter
    def workload_type(self, workload_type):
        """
        Sets the workload_type of this JobExecutionSummary.
        The workload type of the Autonomous Database.


        :param workload_type: The workload_type of this JobExecutionSummary.
        :type: str
        """
        allowed_values = ["OLTP", "DW", "AJD", "APEX"]
        if not value_allowed_none_or_none_sentinel(workload_type, allowed_values):
            workload_type = 'UNKNOWN_ENUM_VALUE'
        self._workload_type = workload_type

    @property
    def job_id(self):
        """
        **[Required]** Gets the job_id of this JobExecutionSummary.
        The `OCID`__ of the parent job.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The job_id of this JobExecutionSummary.
        :rtype: str
        """
        return self._job_id

    @job_id.setter
    def job_id(self, job_id):
        """
        Sets the job_id of this JobExecutionSummary.
        The `OCID`__ of the parent job.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param job_id: The job_id of this JobExecutionSummary.
        :type: str
        """
        self._job_id = job_id

    @property
    def job_name(self):
        """
        **[Required]** Gets the job_name of this JobExecutionSummary.
        The name of the parent job.


        :return: The job_name of this JobExecutionSummary.
        :rtype: str
        """
        return self._job_name

    @job_name.setter
    def job_name(self, job_name):
        """
        Sets the job_name of this JobExecutionSummary.
        The name of the parent job.


        :param job_name: The job_name of this JobExecutionSummary.
        :type: str
        """
        self._job_name = job_name

    @property
    def status(self):
        """
        **[Required]** Gets the status of this JobExecutionSummary.
        The status of the job execution.


        :return: The status of this JobExecutionSummary.
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """
        Sets the status of this JobExecutionSummary.
        The status of the job execution.


        :param status: The status of this JobExecutionSummary.
        :type: str
        """
        self._status = status

    @property
    def time_created(self):
        """
        **[Required]** Gets the time_created of this JobExecutionSummary.
        The date and time when the job execution was created.


        :return: The time_created of this JobExecutionSummary.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this JobExecutionSummary.
        The date and time when the job execution was created.


        :param time_created: The time_created of this JobExecutionSummary.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def time_completed(self):
        """
        Gets the time_completed of this JobExecutionSummary.
        The date and time when the job execution was completed.


        :return: The time_completed of this JobExecutionSummary.
        :rtype: datetime
        """
        return self._time_completed

    @time_completed.setter
    def time_completed(self, time_completed):
        """
        Sets the time_completed of this JobExecutionSummary.
        The date and time when the job execution was completed.


        :param time_completed: The time_completed of this JobExecutionSummary.
        :type: datetime
        """
        self._time_completed = time_completed

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class BdsMetastoreConfiguration(object):
    """
    The metastore configuration information.
    """

    #: A constant which can be used with the metastore_type property of a BdsMetastoreConfiguration.
    #: This constant has a value of "LOCAL"
    METASTORE_TYPE_LOCAL = "LOCAL"

    #: A constant which can be used with the metastore_type property of a BdsMetastoreConfiguration.
    #: This constant has a value of "EXTERNAL"
    METASTORE_TYPE_EXTERNAL = "EXTERNAL"

    #: A constant which can be used with the lifecycle_state property of a BdsMetastoreConfiguration.
    #: This constant has a value of "CREATING"
    LIFECYCLE_STATE_CREATING = "CREATING"

    #: A constant which can be used with the lifecycle_state property of a BdsMetastoreConfiguration.
    #: This constant has a value of "ACTIVATING"
    LIFECYCLE_STATE_ACTIVATING = "ACTIVATING"

    #: A constant which can be used with the lifecycle_state property of a BdsMetastoreConfiguration.
    #: This constant has a value of "ACTIVE"
    LIFECYCLE_STATE_ACTIVE = "ACTIVE"

    #: A constant which can be used with the lifecycle_state property of a BdsMetastoreConfiguration.
    #: This constant has a value of "INACTIVE"
    LIFECYCLE_STATE_INACTIVE = "INACTIVE"

    #: A constant which can be used with the lifecycle_state property of a BdsMetastoreConfiguration.
    #: This constant has a value of "UPDATING"
    LIFECYCLE_STATE_UPDATING = "UPDATING"

    #: A constant which can be used with the lifecycle_state property of a BdsMetastoreConfiguration.
    #: This constant has a value of "FAILED"
    LIFECYCLE_STATE_FAILED = "FAILED"

    #: A constant which can be used with the lifecycle_state property of a BdsMetastoreConfiguration.
    #: This constant has a value of "DELETING"
    LIFECYCLE_STATE_DELETING = "DELETING"

    #: A constant which can be used with the lifecycle_state property of a BdsMetastoreConfiguration.
    #: This constant has a value of "DELETED"
    LIFECYCLE_STATE_DELETED = "DELETED"

    def __init__(self, **kwargs):
        """
        Initializes a new BdsMetastoreConfiguration object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this BdsMetastoreConfiguration.
        :type id: str

        :param display_name:
            The value to assign to the display_name property of this BdsMetastoreConfiguration.
        :type display_name: str

        :param metastore_type:
            The value to assign to the metastore_type property of this BdsMetastoreConfiguration.
            Allowed values for this property are: "LOCAL", "EXTERNAL", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type metastore_type: str

        :param metastore_id:
            The value to assign to the metastore_id property of this BdsMetastoreConfiguration.
        :type metastore_id: str

        :param bds_api_key_id:
            The value to assign to the bds_api_key_id property of this BdsMetastoreConfiguration.
        :type bds_api_key_id: str

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this BdsMetastoreConfiguration.
            Allowed values for this property are: "CREATING", "ACTIVATING", "ACTIVE", "INACTIVE", "UPDATING", "FAILED", "DELETING", "DELETED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param time_created:
            The value to assign to the time_created property of this BdsMetastoreConfiguration.
        :type time_created: datetime

        :param time_updated:
            The value to assign to the time_updated property of this BdsMetastoreConfiguration.
        :type time_updated: datetime

        """
        self.swagger_types = {
            'id': 'str',
            'display_name': 'str',
            'metastore_type': 'str',
            'metastore_id': 'str',
            'bds_api_key_id': 'str',
            'lifecycle_state': 'str',
            'time_created': 'datetime',
            'time_updated': 'datetime'
        }

        self.attribute_map = {
            'id': 'id',
            'display_name': 'displayName',
            'metastore_type': 'metastoreType',
            'metastore_id': 'metastoreId',
            'bds_api_key_id': 'bdsApiKeyId',
            'lifecycle_state': 'lifecycleState',
            'time_created': 'timeCreated',
            'time_updated': 'timeUpdated'
        }

        self._id = None
        self._display_name = None
        self._metastore_type = None
        self._metastore_id = None
        self._bds_api_key_id = None
        self._lifecycle_state = None
        self._time_created = None
        self._time_updated = None

    @property
    def id(self):
        """
        **[Required]** Gets the id of this BdsMetastoreConfiguration.
        The ID of the metastore configuration


        :return: The id of this BdsMetastoreConfiguration.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this BdsMetastoreConfiguration.
        The ID of the metastore configuration


        :param id: The id of this BdsMetastoreConfiguration.
        :type: str
        """
        self._id = id

    @property
    def display_name(self):
        """
        **[Required]** Gets the display_name of this BdsMetastoreConfiguration.
        The display name of metastore configuration


        :return: The display_name of this BdsMetastoreConfiguration.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this BdsMetastoreConfiguration.
        The display name of metastore configuration


        :param display_name: The display_name of this BdsMetastoreConfiguration.
        :type: str
        """
        self._display_name = display_name

    @property
    def metastore_type(self):
        """
        **[Required]** Gets the metastore_type of this BdsMetastoreConfiguration.
        The type of the metastore in the metastore configuration.

        Allowed values for this property are: "LOCAL", "EXTERNAL", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The metastore_type of this BdsMetastoreConfiguration.
        :rtype: str
        """
        return self._metastore_type

    @metastore_type.setter
    def metastore_type(self, metastore_type):
        """
        Sets the metastore_type of this BdsMetastoreConfiguration.
        The type of the metastore in the metastore configuration.


        :param metastore_type: The metastore_type of this BdsMetastoreConfiguration.
        :type: str
        """
        allowed_values = ["LOCAL", "EXTERNAL"]
        if not value_allowed_none_or_none_sentinel(metastore_type, allowed_values):
            metastore_type = 'UNKNOWN_ENUM_VALUE'
        self._metastore_type = metastore_type

    @property
    def metastore_id(self):
        """
        Gets the metastore_id of this BdsMetastoreConfiguration.
        The OCID of the Data Catalog metastore. Set only if metastore's type is EXTERNAL.


        :return: The metastore_id of this BdsMetastoreConfiguration.
        :rtype: str
        """
        return self._metastore_id

    @metastore_id.setter
    def metastore_id(self, metastore_id):
        """
        Sets the metastore_id of this BdsMetastoreConfiguration.
        The OCID of the Data Catalog metastore. Set only if metastore's type is EXTERNAL.


        :param metastore_id: The metastore_id of this BdsMetastoreConfiguration.
        :type: str
        """
        self._metastore_id = metastore_id

    @property
    def bds_api_key_id(self):
        """
        Gets the bds_api_key_id of this BdsMetastoreConfiguration.
        The ID of BDS API Key used for metastore configuration. Set only if metastore's type is EXTERNAL.


        :return: The bds_api_key_id of this BdsMetastoreConfiguration.
        :rtype: str
        """
        return self._bds_api_key_id

    @bds_api_key_id.setter
    def bds_api_key_id(self, bds_api_key_id):
        """
        Sets the bds_api_key_id of this BdsMetastoreConfiguration.
        The ID of BDS API Key used for metastore configuration. Set only if metastore's type is EXTERNAL.


        :param bds_api_key_id: The bds_api_key_id of this BdsMetastoreConfiguration.
        :type: str
        """
        self._bds_api_key_id = bds_api_key_id

    @property
    def lifecycle_state(self):
        """
        **[Required]** Gets the lifecycle_state of this BdsMetastoreConfiguration.
        the lifecycle state of the metastore configuration.

        Allowed values for this property are: "CREATING", "ACTIVATING", "ACTIVE", "INACTIVE", "UPDATING", "FAILED", "DELETING", "DELETED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this BdsMetastoreConfiguration.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this BdsMetastoreConfiguration.
        the lifecycle state of the metastore configuration.


        :param lifecycle_state: The lifecycle_state of this BdsMetastoreConfiguration.
        :type: str
        """
        allowed_values = ["CREATING", "ACTIVATING", "ACTIVE", "INACTIVE", "UPDATING", "FAILED", "DELETING", "DELETED"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    @property
    def time_created(self):
        """
        **[Required]** Gets the time_created of this BdsMetastoreConfiguration.
        The time when the configuration was created, shown as an RFC 3339 formatted datetime string.


        :return: The time_created of this BdsMetastoreConfiguration.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this BdsMetastoreConfiguration.
        The time when the configuration was created, shown as an RFC 3339 formatted datetime string.


        :param time_created: The time_created of this BdsMetastoreConfiguration.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def time_updated(self):
        """
        Gets the time_updated of this BdsMetastoreConfiguration.
        The time when the configuration was updated, shown as an RFC 3339 formatted datetime string.


        :return: The time_updated of this BdsMetastoreConfiguration.
        :rtype: datetime
        """
        return self._time_updated

    @time_updated.setter
    def time_updated(self, time_updated):
        """
        Sets the time_updated of this BdsMetastoreConfiguration.
        The time when the configuration was updated, shown as an RFC 3339 formatted datetime string.


        :param time_updated: The time_updated of this BdsMetastoreConfiguration.
        :type: datetime
        """
        self._time_updated = time_updated

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .format_entry import FormatEntry
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class PPFFormatEntry(FormatEntry):
    """
    The Post Processing Function masking format is a special masking option that
    enables you to use a custom function to further transform column values after
    they have been masked using some other masking formats. It takes the intermediate
    masked values as input and returns the final masked values. For example, you can
    use it for adding checksums or special encodings to the masked values.

    A post-processing function has the same signature as a user-defined function,
    but it passes in the masked values the masking engine generates, and returns
    the final masked values that should be used for masking. To learn more, check
    Post Processing Function in the Data Safe documentation.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new PPFFormatEntry object with values from keyword arguments. The default value of the :py:attr:`~oci.data_safe.models.PPFFormatEntry.type` attribute
        of this class is ``POST_PROCESSING_FUNCTION`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param type:
            The value to assign to the type property of this PPFFormatEntry.
            Allowed values for this property are: "DELETE_ROWS", "DETERMINISTIC_SUBSTITUTION", "DETERMINISTIC_ENCRYPTION", "DETERMINISTIC_ENCRYPTION_DATE", "FIXED_NUMBER", "FIXED_STRING", "LIBRARY_MASKING_FORMAT", "NULL_VALUE", "POST_PROCESSING_FUNCTION", "PRESERVE_ORIGINAL_DATA", "RANDOM_DATE", "RANDOM_DECIMAL_NUMBER", "RANDOM_DIGITS", "RANDOM_LIST", "RANDOM_NUMBER", "RANDOM_STRING", "RANDOM_SUBSTITUTION", "REGULAR_EXPRESSION", "SHUFFLE", "SQL_EXPRESSION", "SUBSTRING", "TRUNCATE_TABLE", "USER_DEFINED_FUNCTION"
        :type type: str

        :param description:
            The value to assign to the description property of this PPFFormatEntry.
        :type description: str

        :param post_processing_function:
            The value to assign to the post_processing_function property of this PPFFormatEntry.
        :type post_processing_function: str

        """
        self.swagger_types = {
            'type': 'str',
            'description': 'str',
            'post_processing_function': 'str'
        }

        self.attribute_map = {
            'type': 'type',
            'description': 'description',
            'post_processing_function': 'postProcessingFunction'
        }

        self._type = None
        self._description = None
        self._post_processing_function = None
        self._type = 'POST_PROCESSING_FUNCTION'

    @property
    def post_processing_function(self):
        """
        **[Required]** Gets the post_processing_function of this PPFFormatEntry.
        The post processing function in SCHEMA_NAME.PACKAGE_NAME.FUNCTION_NAME
        format. It can be a standalone or packaged function, so PACKAGE_NAME
        is optional.


        :return: The post_processing_function of this PPFFormatEntry.
        :rtype: str
        """
        return self._post_processing_function

    @post_processing_function.setter
    def post_processing_function(self, post_processing_function):
        """
        Sets the post_processing_function of this PPFFormatEntry.
        The post processing function in SCHEMA_NAME.PACKAGE_NAME.FUNCTION_NAME
        format. It can be a standalone or packaged function, so PACKAGE_NAME
        is optional.


        :param post_processing_function: The post_processing_function of this PPFFormatEntry.
        :type: str
        """
        self._post_processing_function = post_processing_function

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .create_db_system_source_details import CreateDbSystemSourceDetails
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreateDbSystemSourceFromPitrDetails(CreateDbSystemSourceDetails):
    """
    DB System OCID to perform a point in time recovery to the current point in time.

    DB System OCID and recovery point to perform a point in time recovery to the
    specified recovery point.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new CreateDbSystemSourceFromPitrDetails object with values from keyword arguments. The default value of the :py:attr:`~oci.mysql.models.CreateDbSystemSourceFromPitrDetails.source_type` attribute
        of this class is ``PITR`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param source_type:
            The value to assign to the source_type property of this CreateDbSystemSourceFromPitrDetails.
            Allowed values for this property are: "NONE", "BACKUP", "PITR", "IMPORTURL"
        :type source_type: str

        :param db_system_id:
            The value to assign to the db_system_id property of this CreateDbSystemSourceFromPitrDetails.
        :type db_system_id: str

        :param recovery_point:
            The value to assign to the recovery_point property of this CreateDbSystemSourceFromPitrDetails.
        :type recovery_point: datetime

        """
        self.swagger_types = {
            'source_type': 'str',
            'db_system_id': 'str',
            'recovery_point': 'datetime'
        }

        self.attribute_map = {
            'source_type': 'sourceType',
            'db_system_id': 'dbSystemId',
            'recovery_point': 'recoveryPoint'
        }

        self._source_type = None
        self._db_system_id = None
        self._recovery_point = None
        self._source_type = 'PITR'

    @property
    def db_system_id(self):
        """
        **[Required]** Gets the db_system_id of this CreateDbSystemSourceFromPitrDetails.
        The OCID of the DB System from which a backup shall be selected to be
        restored when creating the new DB System. Use this together with
        recovery point to perform a point in time recovery operation.


        :return: The db_system_id of this CreateDbSystemSourceFromPitrDetails.
        :rtype: str
        """
        return self._db_system_id

    @db_system_id.setter
    def db_system_id(self, db_system_id):
        """
        Sets the db_system_id of this CreateDbSystemSourceFromPitrDetails.
        The OCID of the DB System from which a backup shall be selected to be
        restored when creating the new DB System. Use this together with
        recovery point to perform a point in time recovery operation.


        :param db_system_id: The db_system_id of this CreateDbSystemSourceFromPitrDetails.
        :type: str
        """
        self._db_system_id = db_system_id

    @property
    def recovery_point(self):
        """
        Gets the recovery_point of this CreateDbSystemSourceFromPitrDetails.
        The date and time, as per RFC 3339, of the change up to which the
        new DB System shall be restored to, using a backup and logs from the
        original DB System. In case no point in time is specified, then this
        new DB System shall be restored up to the latest change recorded for
        the original DB System.


        :return: The recovery_point of this CreateDbSystemSourceFromPitrDetails.
        :rtype: datetime
        """
        return self._recovery_point

    @recovery_point.setter
    def recovery_point(self, recovery_point):
        """
        Sets the recovery_point of this CreateDbSystemSourceFromPitrDetails.
        The date and time, as per RFC 3339, of the change up to which the
        new DB System shall be restored to, using a backup and logs from the
        original DB System. In case no point in time is specified, then this
        new DB System shall be restored up to the latest change recorded for
        the original DB System.


        :param recovery_point: The recovery_point of this CreateDbSystemSourceFromPitrDetails.
        :type: datetime
        """
        self._recovery_point = recovery_point

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ApplicationScanSettings(object):
    """
    Agent scan settings for applicaiton scan
    """

    def __init__(self, **kwargs):
        """
        Initializes a new ApplicationScanSettings object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param application_scan_recurrence:
            The value to assign to the application_scan_recurrence property of this ApplicationScanSettings.
        :type application_scan_recurrence: str

        :param is_enabled:
            The value to assign to the is_enabled property of this ApplicationScanSettings.
        :type is_enabled: bool

        :param folders_to_scan:
            The value to assign to the folders_to_scan property of this ApplicationScanSettings.
        :type folders_to_scan: list[oci.vulnerability_scanning.models.FolderToScan]

        """
        self.swagger_types = {
            'application_scan_recurrence': 'str',
            'is_enabled': 'bool',
            'folders_to_scan': 'list[FolderToScan]'
        }

        self.attribute_map = {
            'application_scan_recurrence': 'applicationScanRecurrence',
            'is_enabled': 'isEnabled',
            'folders_to_scan': 'foldersToScan'
        }

        self._application_scan_recurrence = None
        self._is_enabled = None
        self._folders_to_scan = None

    @property
    def application_scan_recurrence(self):
        """
        **[Required]** Gets the application_scan_recurrence of this ApplicationScanSettings.
        Scan recurrences in RFC-5545 section 3.3.10 format.
        Only supported input are weekly, biweekly, monthly listed below
        FREQ=WEEKLY;WKST=<weekday>;INTERVAL=1 - This weekly scan on the specified weekday (e.g. Sunday)
        FREQ=WEEKLY;WKST=<weekday>;INTERVAL=2 - This bi-weekly scan on the specified weekday (e.g. Sunday)
        FREQ=MONTHLY;WKST=<weekday>;INTERVAL=1 - This monthly scan on the specified weekday (e.g. Sunday, starting from the next such weekday based on the time of setting creation)


        :return: The application_scan_recurrence of this ApplicationScanSettings.
        :rtype: str
        """
        return self._application_scan_recurrence

    @application_scan_recurrence.setter
    def application_scan_recurrence(self, application_scan_recurrence):
        """
        Sets the application_scan_recurrence of this ApplicationScanSettings.
        Scan recurrences in RFC-5545 section 3.3.10 format.
        Only supported input are weekly, biweekly, monthly listed below
        FREQ=WEEKLY;WKST=<weekday>;INTERVAL=1 - This weekly scan on the specified weekday (e.g. Sunday)
        FREQ=WEEKLY;WKST=<weekday>;INTERVAL=2 - This bi-weekly scan on the specified weekday (e.g. Sunday)
        FREQ=MONTHLY;WKST=<weekday>;INTERVAL=1 - This monthly scan on the specified weekday (e.g. Sunday, starting from the next such weekday based on the time of setting creation)


        :param application_scan_recurrence: The application_scan_recurrence of this ApplicationScanSettings.
        :type: str
        """
        self._application_scan_recurrence = application_scan_recurrence

    @property
    def is_enabled(self):
        """
        **[Required]** Gets the is_enabled of this ApplicationScanSettings.
        Enable or disable application scan


        :return: The is_enabled of this ApplicationScanSettings.
        :rtype: bool
        """
        return self._is_enabled

    @is_enabled.setter
    def is_enabled(self, is_enabled):
        """
        Sets the is_enabled of this ApplicationScanSettings.
        Enable or disable application scan


        :param is_enabled: The is_enabled of this ApplicationScanSettings.
        :type: bool
        """
        self._is_enabled = is_enabled

    @property
    def folders_to_scan(self):
        """
        **[Required]** Gets the folders_to_scan of this ApplicationScanSettings.
        List of folders selected for scanning


        :return: The folders_to_scan of this ApplicationScanSettings.
        :rtype: list[oci.vulnerability_scanning.models.FolderToScan]
        """
        return self._folders_to_scan

    @folders_to_scan.setter
    def folders_to_scan(self, folders_to_scan):
        """
        Sets the folders_to_scan of this ApplicationScanSettings.
        List of folders selected for scanning


        :param folders_to_scan: The folders_to_scan of this ApplicationScanSettings.
        :type: list[oci.vulnerability_scanning.models.FolderToScan]
        """
        self._folders_to_scan = folders_to_scan

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class PaySubscriptionReceipt(object):
    """
    Subscription payment action response
    """

    def __init__(self, **kwargs):
        """
        Initializes a new PaySubscriptionReceipt object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param header_id:
            The value to assign to the header_id property of this PaySubscriptionReceipt.
        :type header_id: str

        :param api_token:
            The value to assign to the api_token property of this PaySubscriptionReceipt.
        :type api_token: str

        :param user_token:
            The value to assign to the user_token property of this PaySubscriptionReceipt.
        :type user_token: str

        """
        self.swagger_types = {
            'header_id': 'str',
            'api_token': 'str',
            'user_token': 'str'
        }

        self.attribute_map = {
            'header_id': 'headerId',
            'api_token': 'apiToken',
            'user_token': 'userToken'
        }

        self._header_id = None
        self._api_token = None
        self._user_token = None

    @property
    def header_id(self):
        """
        **[Required]** Gets the header_id of this PaySubscriptionReceipt.
        Payment header id


        :return: The header_id of this PaySubscriptionReceipt.
        :rtype: str
        """
        return self._header_id

    @header_id.setter
    def header_id(self, header_id):
        """
        Sets the header_id of this PaySubscriptionReceipt.
        Payment header id


        :param header_id: The header_id of this PaySubscriptionReceipt.
        :type: str
        """
        self._header_id = header_id

    @property
    def api_token(self):
        """
        Gets the api_token of this PaySubscriptionReceipt.
        Parameters in a token for Payment Service


        :return: The api_token of this PaySubscriptionReceipt.
        :rtype: str
        """
        return self._api_token

    @api_token.setter
    def api_token(self, api_token):
        """
        Sets the api_token of this PaySubscriptionReceipt.
        Parameters in a token for Payment Service


        :param api_token: The api_token of this PaySubscriptionReceipt.
        :type: str
        """
        self._api_token = api_token

    @property
    def user_token(self):
        """
        Gets the user_token of this PaySubscriptionReceipt.
        Session token created for Payment Service


        :return: The user_token of this PaySubscriptionReceipt.
        :rtype: str
        """
        return self._user_token

    @user_token.setter
    def user_token(self, user_token):
        """
        Sets the user_token of this PaySubscriptionReceipt.
        Session token created for Payment Service


        :param user_token: The user_token of this PaySubscriptionReceipt.
        :type: str
        """
        self._user_token = user_token

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .update_exadata_insight_details import UpdateExadataInsightDetails
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class UpdateEmManagedExternalExadataInsightDetails(UpdateExadataInsightDetails):
    """
    The information to be updated.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new UpdateEmManagedExternalExadataInsightDetails object with values from keyword arguments. The default value of the :py:attr:`~oci.opsi.models.UpdateEmManagedExternalExadataInsightDetails.entity_source` attribute
        of this class is ``EM_MANAGED_EXTERNAL_EXADATA`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param entity_source:
            The value to assign to the entity_source property of this UpdateEmManagedExternalExadataInsightDetails.
            Allowed values for this property are: "EM_MANAGED_EXTERNAL_EXADATA"
        :type entity_source: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this UpdateEmManagedExternalExadataInsightDetails.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this UpdateEmManagedExternalExadataInsightDetails.
        :type defined_tags: dict(str, dict(str, object))

        :param is_auto_sync_enabled:
            The value to assign to the is_auto_sync_enabled property of this UpdateEmManagedExternalExadataInsightDetails.
        :type is_auto_sync_enabled: bool

        """
        self.swagger_types = {
            'entity_source': 'str',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))',
            'is_auto_sync_enabled': 'bool'
        }

        self.attribute_map = {
            'entity_source': 'entitySource',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags',
            'is_auto_sync_enabled': 'isAutoSyncEnabled'
        }

        self._entity_source = None
        self._freeform_tags = None
        self._defined_tags = None
        self._is_auto_sync_enabled = None
        self._entity_source = 'EM_MANAGED_EXTERNAL_EXADATA'

    @property
    def is_auto_sync_enabled(self):
        """
        Gets the is_auto_sync_enabled of this UpdateEmManagedExternalExadataInsightDetails.
        Set to true to enable automatic enablement and disablement of related targets from Enterprise Manager. New resources (e.g. Database Insights) will be placed in the same compartment as the related Exadata Insight.


        :return: The is_auto_sync_enabled of this UpdateEmManagedExternalExadataInsightDetails.
        :rtype: bool
        """
        return self._is_auto_sync_enabled

    @is_auto_sync_enabled.setter
    def is_auto_sync_enabled(self, is_auto_sync_enabled):
        """
        Sets the is_auto_sync_enabled of this UpdateEmManagedExternalExadataInsightDetails.
        Set to true to enable automatic enablement and disablement of related targets from Enterprise Manager. New resources (e.g. Database Insights) will be placed in the same compartment as the related Exadata Insight.


        :param is_auto_sync_enabled: The is_auto_sync_enabled of this UpdateEmManagedExternalExadataInsightDetails.
        :type: bool
        """
        self._is_auto_sync_enabled = is_auto_sync_enabled

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class UpdateCertificateDetails(object):
    """
    The details of the certificate to update.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new UpdateCertificateDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param description:
            The value to assign to the description property of this UpdateCertificateDetails.
        :type description: str

        :param current_version_number:
            The value to assign to the current_version_number property of this UpdateCertificateDetails.
        :type current_version_number: int

        :param certificate_config:
            The value to assign to the certificate_config property of this UpdateCertificateDetails.
        :type certificate_config: oci.certificates_management.models.UpdateCertificateConfigDetails

        :param freeform_tags:
            The value to assign to the freeform_tags property of this UpdateCertificateDetails.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this UpdateCertificateDetails.
        :type defined_tags: dict(str, dict(str, object))

        :param certificate_rules:
            The value to assign to the certificate_rules property of this UpdateCertificateDetails.
        :type certificate_rules: list[oci.certificates_management.models.CertificateRule]

        """
        self.swagger_types = {
            'description': 'str',
            'current_version_number': 'int',
            'certificate_config': 'UpdateCertificateConfigDetails',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))',
            'certificate_rules': 'list[CertificateRule]'
        }

        self.attribute_map = {
            'description': 'description',
            'current_version_number': 'currentVersionNumber',
            'certificate_config': 'certificateConfig',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags',
            'certificate_rules': 'certificateRules'
        }

        self._description = None
        self._current_version_number = None
        self._certificate_config = None
        self._freeform_tags = None
        self._defined_tags = None
        self._certificate_rules = None

    @property
    def description(self):
        """
        Gets the description of this UpdateCertificateDetails.
        A brief description of the certificate. Avoid entering confidential information.


        :return: The description of this UpdateCertificateDetails.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this UpdateCertificateDetails.
        A brief description of the certificate. Avoid entering confidential information.


        :param description: The description of this UpdateCertificateDetails.
        :type: str
        """
        self._description = description

    @property
    def current_version_number(self):
        """
        Gets the current_version_number of this UpdateCertificateDetails.
        Makes this version the current version. This property cannot be updated in combination with any other properties.


        :return: The current_version_number of this UpdateCertificateDetails.
        :rtype: int
        """
        return self._current_version_number

    @current_version_number.setter
    def current_version_number(self, current_version_number):
        """
        Sets the current_version_number of this UpdateCertificateDetails.
        Makes this version the current version. This property cannot be updated in combination with any other properties.


        :param current_version_number: The current_version_number of this UpdateCertificateDetails.
        :type: int
        """
        self._current_version_number = current_version_number

    @property
    def certificate_config(self):
        """
        Gets the certificate_config of this UpdateCertificateDetails.

        :return: The certificate_config of this UpdateCertificateDetails.
        :rtype: oci.certificates_management.models.UpdateCertificateConfigDetails
        """
        return self._certificate_config

    @certificate_config.setter
    def certificate_config(self, certificate_config):
        """
        Sets the certificate_config of this UpdateCertificateDetails.

        :param certificate_config: The certificate_config of this UpdateCertificateDetails.
        :type: oci.certificates_management.models.UpdateCertificateConfigDetails
        """
        self._certificate_config = certificate_config

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this UpdateCertificateDetails.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace.
        For more information, see `Resource Tags`__.
        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The freeform_tags of this UpdateCertificateDetails.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this UpdateCertificateDetails.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace.
        For more information, see `Resource Tags`__.
        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param freeform_tags: The freeform_tags of this UpdateCertificateDetails.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this UpdateCertificateDetails.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        For more information, see `Resource Tags`__.
        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The defined_tags of this UpdateCertificateDetails.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this UpdateCertificateDetails.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        For more information, see `Resource Tags`__.
        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param defined_tags: The defined_tags of this UpdateCertificateDetails.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    @property
    def certificate_rules(self):
        """
        Gets the certificate_rules of this UpdateCertificateDetails.
        An optional list of rules that control how the certificate is used and managed.


        :return: The certificate_rules of this UpdateCertificateDetails.
        :rtype: list[oci.certificates_management.models.CertificateRule]
        """
        return self._certificate_rules

    @certificate_rules.setter
    def certificate_rules(self, certificate_rules):
        """
        Sets the certificate_rules of this UpdateCertificateDetails.
        An optional list of rules that control how the certificate is used and managed.


        :param certificate_rules: The certificate_rules of this UpdateCertificateDetails.
        :type: list[oci.certificates_management.models.CertificateRule]
        """
        self._certificate_rules = certificate_rules

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class RecordAggregationDimensions(object):
    """
    The dimensions to summarize record information for a given dataset.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new RecordAggregationDimensions object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param is_labeled:
            The value to assign to the is_labeled property of this RecordAggregationDimensions.
        :type is_labeled: bool

        :param annotation_label_contains:
            The value to assign to the annotation_label_contains property of this RecordAggregationDimensions.
        :type annotation_label_contains: str

        """
        self.swagger_types = {
            'is_labeled': 'bool',
            'annotation_label_contains': 'str'
        }

        self.attribute_map = {
            'is_labeled': 'isLabeled',
            'annotation_label_contains': 'annotationLabelContains'
        }

        self._is_labeled = None
        self._annotation_label_contains = None

    @property
    def is_labeled(self):
        """
        Gets the is_labeled of this RecordAggregationDimensions.
        Whether or not the record has been labeled and has associated annotations.


        :return: The is_labeled of this RecordAggregationDimensions.
        :rtype: bool
        """
        return self._is_labeled

    @is_labeled.setter
    def is_labeled(self, is_labeled):
        """
        Sets the is_labeled of this RecordAggregationDimensions.
        Whether or not the record has been labeled and has associated annotations.


        :param is_labeled: The is_labeled of this RecordAggregationDimensions.
        :type: bool
        """
        self._is_labeled = is_labeled

    @property
    def annotation_label_contains(self):
        """
        Gets the annotation_label_contains of this RecordAggregationDimensions.
        Whether or not the annotation contains a label.


        :return: The annotation_label_contains of this RecordAggregationDimensions.
        :rtype: str
        """
        return self._annotation_label_contains

    @annotation_label_contains.setter
    def annotation_label_contains(self, annotation_label_contains):
        """
        Sets the annotation_label_contains of this RecordAggregationDimensions.
        Whether or not the annotation contains a label.


        :param annotation_label_contains: The annotation_label_contains of this RecordAggregationDimensions.
        :type: str
        """
        self._annotation_label_contains = annotation_label_contains

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class UpdateCertificateAuthorityDetails(object):
    """
    The details for updating a certificate authority (CA).
    """

    def __init__(self, **kwargs):
        """
        Initializes a new UpdateCertificateAuthorityDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param description:
            The value to assign to the description property of this UpdateCertificateAuthorityDetails.
        :type description: str

        :param current_version_number:
            The value to assign to the current_version_number property of this UpdateCertificateAuthorityDetails.
        :type current_version_number: int

        :param certificate_authority_config:
            The value to assign to the certificate_authority_config property of this UpdateCertificateAuthorityDetails.
        :type certificate_authority_config: oci.certificates_management.models.UpdateCertificateAuthorityConfigDetails

        :param certificate_revocation_list_details:
            The value to assign to the certificate_revocation_list_details property of this UpdateCertificateAuthorityDetails.
        :type certificate_revocation_list_details: oci.certificates_management.models.CertificateRevocationListDetails

        :param freeform_tags:
            The value to assign to the freeform_tags property of this UpdateCertificateAuthorityDetails.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this UpdateCertificateAuthorityDetails.
        :type defined_tags: dict(str, dict(str, object))

        :param certificate_authority_rules:
            The value to assign to the certificate_authority_rules property of this UpdateCertificateAuthorityDetails.
        :type certificate_authority_rules: list[oci.certificates_management.models.CertificateAuthorityRule]

        """
        self.swagger_types = {
            'description': 'str',
            'current_version_number': 'int',
            'certificate_authority_config': 'UpdateCertificateAuthorityConfigDetails',
            'certificate_revocation_list_details': 'CertificateRevocationListDetails',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))',
            'certificate_authority_rules': 'list[CertificateAuthorityRule]'
        }

        self.attribute_map = {
            'description': 'description',
            'current_version_number': 'currentVersionNumber',
            'certificate_authority_config': 'certificateAuthorityConfig',
            'certificate_revocation_list_details': 'certificateRevocationListDetails',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags',
            'certificate_authority_rules': 'certificateAuthorityRules'
        }

        self._description = None
        self._current_version_number = None
        self._certificate_authority_config = None
        self._certificate_revocation_list_details = None
        self._freeform_tags = None
        self._defined_tags = None
        self._certificate_authority_rules = None

    @property
    def description(self):
        """
        Gets the description of this UpdateCertificateAuthorityDetails.
        A brief description of the CA.


        :return: The description of this UpdateCertificateAuthorityDetails.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this UpdateCertificateAuthorityDetails.
        A brief description of the CA.


        :param description: The description of this UpdateCertificateAuthorityDetails.
        :type: str
        """
        self._description = description

    @property
    def current_version_number(self):
        """
        Gets the current_version_number of this UpdateCertificateAuthorityDetails.
        Makes this version the current version. This property cannot be updated in combination with any other properties.


        :return: The current_version_number of this UpdateCertificateAuthorityDetails.
        :rtype: int
        """
        return self._current_version_number

    @current_version_number.setter
    def current_version_number(self, current_version_number):
        """
        Sets the current_version_number of this UpdateCertificateAuthorityDetails.
        Makes this version the current version. This property cannot be updated in combination with any other properties.


        :param current_version_number: The current_version_number of this UpdateCertificateAuthorityDetails.
        :type: int
        """
        self._current_version_number = current_version_number

    @property
    def certificate_authority_config(self):
        """
        Gets the certificate_authority_config of this UpdateCertificateAuthorityDetails.

        :return: The certificate_authority_config of this UpdateCertificateAuthorityDetails.
        :rtype: oci.certificates_management.models.UpdateCertificateAuthorityConfigDetails
        """
        return self._certificate_authority_config

    @certificate_authority_config.setter
    def certificate_authority_config(self, certificate_authority_config):
        """
        Sets the certificate_authority_config of this UpdateCertificateAuthorityDetails.

        :param certificate_authority_config: The certificate_authority_config of this UpdateCertificateAuthorityDetails.
        :type: oci.certificates_management.models.UpdateCertificateAuthorityConfigDetails
        """
        self._certificate_authority_config = certificate_authority_config

    @property
    def certificate_revocation_list_details(self):
        """
        Gets the certificate_revocation_list_details of this UpdateCertificateAuthorityDetails.

        :return: The certificate_revocation_list_details of this UpdateCertificateAuthorityDetails.
        :rtype: oci.certificates_management.models.CertificateRevocationListDetails
        """
        return self._certificate_revocation_list_details

    @certificate_revocation_list_details.setter
    def certificate_revocation_list_details(self, certificate_revocation_list_details):
        """
        Sets the certificate_revocation_list_details of this UpdateCertificateAuthorityDetails.

        :param certificate_revocation_list_details: The certificate_revocation_list_details of this UpdateCertificateAuthorityDetails.
        :type: oci.certificates_management.models.CertificateRevocationListDetails
        """
        self._certificate_revocation_list_details = certificate_revocation_list_details

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this UpdateCertificateAuthorityDetails.
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
        Example: `{\"bar-key\": \"value\"}`


        :return: The freeform_tags of this UpdateCertificateAuthorityDetails.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this UpdateCertificateAuthorityDetails.
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
        Example: `{\"bar-key\": \"value\"}`


        :param freeform_tags: The freeform_tags of this UpdateCertificateAuthorityDetails.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this UpdateCertificateAuthorityDetails.
        Usage of predefined tag keys. These predefined keys are scoped to namespaces.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :return: The defined_tags of this UpdateCertificateAuthorityDetails.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this UpdateCertificateAuthorityDetails.
        Usage of predefined tag keys. These predefined keys are scoped to namespaces.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :param defined_tags: The defined_tags of this UpdateCertificateAuthorityDetails.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    @property
    def certificate_authority_rules(self):
        """
        Gets the certificate_authority_rules of this UpdateCertificateAuthorityDetails.
        A list of rules that control how the CA is used and managed.


        :return: The certificate_authority_rules of this UpdateCertificateAuthorityDetails.
        :rtype: list[oci.certificates_management.models.CertificateAuthorityRule]
        """
        return self._certificate_authority_rules

    @certificate_authority_rules.setter
    def certificate_authority_rules(self, certificate_authority_rules):
        """
        Sets the certificate_authority_rules of this UpdateCertificateAuthorityDetails.
        A list of rules that control how the CA is used and managed.


        :param certificate_authority_rules: The certificate_authority_rules of this UpdateCertificateAuthorityDetails.
        :type: list[oci.certificates_management.models.CertificateAuthorityRule]
        """
        self._certificate_authority_rules = certificate_authority_rules

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class Package(object):
    """
    Details of the vulnerable package found
    """

    #: A constant which can be used with the type property of a Package.
    #: This constant has a value of "JAVA"
    TYPE_JAVA = "JAVA"

    #: A constant which can be used with the type property of a Package.
    #: This constant has a value of "APK"
    TYPE_APK = "APK"

    #: A constant which can be used with the type property of a Package.
    #: This constant has a value of "RPM"
    TYPE_RPM = "RPM"

    #: A constant which can be used with the type property of a Package.
    #: This constant has a value of "DEB"
    TYPE_DEB = "DEB"

    #: A constant which can be used with the type property of a Package.
    #: This constant has a value of "GO"
    TYPE_GO = "GO"

    #: A constant which can be used with the type property of a Package.
    #: This constant has a value of "NPM"
    TYPE_NPM = "NPM"

    #: A constant which can be used with the type property of a Package.
    #: This constant has a value of "PYTHON"
    TYPE_PYTHON = "PYTHON"

    #: A constant which can be used with the type property of a Package.
    #: This constant has a value of "RUST"
    TYPE_RUST = "RUST"

    #: A constant which can be used with the type property of a Package.
    #: This constant has a value of "PHP_COMPOSER"
    TYPE_PHP_COMPOSER = "PHP_COMPOSER"

    #: A constant which can be used with the type property of a Package.
    #: This constant has a value of "GEM"
    TYPE_GEM = "GEM"

    #: A constant which can be used with the type property of a Package.
    #: This constant has a value of "MSRC_KB"
    TYPE_MSRC_KB = "MSRC_KB"

    def __init__(self, **kwargs):
        """
        Initializes a new Package object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param name:
            The value to assign to the name property of this Package.
        :type name: str

        :param version:
            The value to assign to the version property of this Package.
        :type version: str

        :param cve_fix_version:
            The value to assign to the cve_fix_version property of this Package.
        :type cve_fix_version: str

        :param type:
            The value to assign to the type property of this Package.
            Allowed values for this property are: "JAVA", "APK", "RPM", "DEB", "GO", "NPM", "PYTHON", "RUST", "PHP_COMPOSER", "GEM", "MSRC_KB", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type type: str

        :param locations:
            The value to assign to the locations property of this Package.
        :type locations: list[str]

        """
        self.swagger_types = {
            'name': 'str',
            'version': 'str',
            'cve_fix_version': 'str',
            'type': 'str',
            'locations': 'list[str]'
        }

        self.attribute_map = {
            'name': 'name',
            'version': 'version',
            'cve_fix_version': 'cveFixVersion',
            'type': 'type',
            'locations': 'locations'
        }

        self._name = None
        self._version = None
        self._cve_fix_version = None
        self._type = None
        self._locations = None

    @property
    def name(self):
        """
        **[Required]** Gets the name of this Package.
        Name of the package


        :return: The name of this Package.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this Package.
        Name of the package


        :param name: The name of this Package.
        :type: str
        """
        self._name = name

    @property
    def version(self):
        """
        **[Required]** Gets the version of this Package.
        Package version


        :return: The version of this Package.
        :rtype: str
        """
        return self._version

    @version.setter
    def version(self, version):
        """
        Sets the version of this Package.
        Package version


        :param version: The version of this Package.
        :type: str
        """
        self._version = version

    @property
    def cve_fix_version(self):
        """
        Gets the cve_fix_version of this Package.
        Package version in which the CVE was fixed


        :return: The cve_fix_version of this Package.
        :rtype: str
        """
        return self._cve_fix_version

    @cve_fix_version.setter
    def cve_fix_version(self, cve_fix_version):
        """
        Sets the cve_fix_version of this Package.
        Package version in which the CVE was fixed


        :param cve_fix_version: The cve_fix_version of this Package.
        :type: str
        """
        self._cve_fix_version = cve_fix_version

    @property
    def type(self):
        """
        **[Required]** Gets the type of this Package.
        Package type

        Allowed values for this property are: "JAVA", "APK", "RPM", "DEB", "GO", "NPM", "PYTHON", "RUST", "PHP_COMPOSER", "GEM", "MSRC_KB", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The type of this Package.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this Package.
        Package type


        :param type: The type of this Package.
        :type: str
        """
        allowed_values = ["JAVA", "APK", "RPM", "DEB", "GO", "NPM", "PYTHON", "RUST", "PHP_COMPOSER", "GEM", "MSRC_KB"]
        if not value_allowed_none_or_none_sentinel(type, allowed_values):
            type = 'UNKNOWN_ENUM_VALUE'
        self._type = type

    @property
    def locations(self):
        """
        Gets the locations of this Package.
        Disk locations where package was found


        :return: The locations of this Package.
        :rtype: list[str]
        """
        return self._locations

    @locations.setter
    def locations(self, locations):
        """
        Sets the locations of this Package.
        Disk locations where package was found


        :param locations: The locations of this Package.
        :type: list[str]
        """
        self._locations = locations

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class DiffResponse(object):
    """
    Response object for obtaining list of changed files.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new DiffResponse object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param are_all_changes_included:
            The value to assign to the are_all_changes_included property of this DiffResponse.
        :type are_all_changes_included: bool

        :param change_type_count:
            The value to assign to the change_type_count property of this DiffResponse.
        :type change_type_count: dict(str, int)

        :param common_commit:
            The value to assign to the common_commit property of this DiffResponse.
        :type common_commit: str

        :param commits_ahead_count:
            The value to assign to the commits_ahead_count property of this DiffResponse.
        :type commits_ahead_count: int

        :param commits_behind_count:
            The value to assign to the commits_behind_count property of this DiffResponse.
        :type commits_behind_count: int

        :param added_lines_count:
            The value to assign to the added_lines_count property of this DiffResponse.
        :type added_lines_count: int

        :param deleted_lines_count:
            The value to assign to the deleted_lines_count property of this DiffResponse.
        :type deleted_lines_count: int

        :param changes:
            The value to assign to the changes property of this DiffResponse.
        :type changes: list[oci.devops.models.DiffResponseEntry]

        """
        self.swagger_types = {
            'are_all_changes_included': 'bool',
            'change_type_count': 'dict(str, int)',
            'common_commit': 'str',
            'commits_ahead_count': 'int',
            'commits_behind_count': 'int',
            'added_lines_count': 'int',
            'deleted_lines_count': 'int',
            'changes': 'list[DiffResponseEntry]'
        }

        self.attribute_map = {
            'are_all_changes_included': 'areAllChangesIncluded',
            'change_type_count': 'changeTypeCount',
            'common_commit': 'commonCommit',
            'commits_ahead_count': 'commitsAheadCount',
            'commits_behind_count': 'commitsBehindCount',
            'added_lines_count': 'addedLinesCount',
            'deleted_lines_count': 'deletedLinesCount',
            'changes': 'changes'
        }

        self._are_all_changes_included = None
        self._change_type_count = None
        self._common_commit = None
        self._commits_ahead_count = None
        self._commits_behind_count = None
        self._added_lines_count = None
        self._deleted_lines_count = None
        self._changes = None

    @property
    def are_all_changes_included(self):
        """
        Gets the are_all_changes_included of this DiffResponse.
        Boolean value to indicate if all changes are included in the response.


        :return: The are_all_changes_included of this DiffResponse.
        :rtype: bool
        """
        return self._are_all_changes_included

    @are_all_changes_included.setter
    def are_all_changes_included(self, are_all_changes_included):
        """
        Sets the are_all_changes_included of this DiffResponse.
        Boolean value to indicate if all changes are included in the response.


        :param are_all_changes_included: The are_all_changes_included of this DiffResponse.
        :type: bool
        """
        self._are_all_changes_included = are_all_changes_included

    @property
    def change_type_count(self):
        """
        Gets the change_type_count of this DiffResponse.
        Count of each type of change in difference.


        :return: The change_type_count of this DiffResponse.
        :rtype: dict(str, int)
        """
        return self._change_type_count

    @change_type_count.setter
    def change_type_count(self, change_type_count):
        """
        Sets the change_type_count of this DiffResponse.
        Count of each type of change in difference.


        :param change_type_count: The change_type_count of this DiffResponse.
        :type: dict(str, int)
        """
        self._change_type_count = change_type_count

    @property
    def common_commit(self):
        """
        Gets the common_commit of this DiffResponse.
        The ID of the common commit between source and target.


        :return: The common_commit of this DiffResponse.
        :rtype: str
        """
        return self._common_commit

    @common_commit.setter
    def common_commit(self, common_commit):
        """
        Sets the common_commit of this DiffResponse.
        The ID of the common commit between source and target.


        :param common_commit: The common_commit of this DiffResponse.
        :type: str
        """
        self._common_commit = common_commit

    @property
    def commits_ahead_count(self):
        """
        Gets the commits_ahead_count of this DiffResponse.
        The number of commits source is ahead of target by.


        :return: The commits_ahead_count of this DiffResponse.
        :rtype: int
        """
        return self._commits_ahead_count

    @commits_ahead_count.setter
    def commits_ahead_count(self, commits_ahead_count):
        """
        Sets the commits_ahead_count of this DiffResponse.
        The number of commits source is ahead of target by.


        :param commits_ahead_count: The commits_ahead_count of this DiffResponse.
        :type: int
        """
        self._commits_ahead_count = commits_ahead_count

    @property
    def commits_behind_count(self):
        """
        Gets the commits_behind_count of this DiffResponse.
        The number of commits source is behind target by.


        :return: The commits_behind_count of this DiffResponse.
        :rtype: int
        """
        return self._commits_behind_count

    @commits_behind_count.setter
    def commits_behind_count(self, commits_behind_count):
        """
        Sets the commits_behind_count of this DiffResponse.
        The number of commits source is behind target by.


        :param commits_behind_count: The commits_behind_count of this DiffResponse.
        :type: int
        """
        self._commits_behind_count = commits_behind_count

    @property
    def added_lines_count(self):
        """
        Gets the added_lines_count of this DiffResponse.
        The number of lines added in whole difference.


        :return: The added_lines_count of this DiffResponse.
        :rtype: int
        """
        return self._added_lines_count

    @added_lines_count.setter
    def added_lines_count(self, added_lines_count):
        """
        Sets the added_lines_count of this DiffResponse.
        The number of lines added in whole difference.


        :param added_lines_count: The added_lines_count of this DiffResponse.
        :type: int
        """
        self._added_lines_count = added_lines_count

    @property
    def deleted_lines_count(self):
        """
        Gets the deleted_lines_count of this DiffResponse.
        The number of lines deleted in whole difference.


        :return: The deleted_lines_count of this DiffResponse.
        :rtype: int
        """
        return self._deleted_lines_count

    @deleted_lines_count.setter
    def deleted_lines_count(self, deleted_lines_count):
        """
        Sets the deleted_lines_count of this DiffResponse.
        The number of lines deleted in whole difference.


        :param deleted_lines_count: The deleted_lines_count of this DiffResponse.
        :type: int
        """
        self._deleted_lines_count = deleted_lines_count

    @property
    def changes(self):
        """
        **[Required]** Gets the changes of this DiffResponse.
        List of changes in the difference.


        :return: The changes of this DiffResponse.
        :rtype: list[oci.devops.models.DiffResponseEntry]
        """
        return self._changes

    @changes.setter
    def changes(self, changes):
        """
        Sets the changes of this DiffResponse.
        List of changes in the difference.


        :param changes: The changes of this DiffResponse.
        :type: list[oci.devops.models.DiffResponseEntry]
        """
        self._changes = changes

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class SearchMonitoredResourceAssociationsDetails(object):
    """
    The information required to search monitored resource associations.
    """

    #: A constant which can be used with the sort_by property of a SearchMonitoredResourceAssociationsDetails.
    #: This constant has a value of "TIME_CREATED"
    SORT_BY_TIME_CREATED = "TIME_CREATED"

    #: A constant which can be used with the sort_by property of a SearchMonitoredResourceAssociationsDetails.
    #: This constant has a value of "ASSOC_TYPE"
    SORT_BY_ASSOC_TYPE = "ASSOC_TYPE"

    #: A constant which can be used with the sort_order property of a SearchMonitoredResourceAssociationsDetails.
    #: This constant has a value of "ASC"
    SORT_ORDER_ASC = "ASC"

    #: A constant which can be used with the sort_order property of a SearchMonitoredResourceAssociationsDetails.
    #: This constant has a value of "DESC"
    SORT_ORDER_DESC = "DESC"

    def __init__(self, **kwargs):
        """
        Initializes a new SearchMonitoredResourceAssociationsDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param compartment_id:
            The value to assign to the compartment_id property of this SearchMonitoredResourceAssociationsDetails.
        :type compartment_id: str

        :param source_resource_id:
            The value to assign to the source_resource_id property of this SearchMonitoredResourceAssociationsDetails.
        :type source_resource_id: str

        :param source_resource_name:
            The value to assign to the source_resource_name property of this SearchMonitoredResourceAssociationsDetails.
        :type source_resource_name: str

        :param source_resource_type:
            The value to assign to the source_resource_type property of this SearchMonitoredResourceAssociationsDetails.
        :type source_resource_type: str

        :param destination_resource_id:
            The value to assign to the destination_resource_id property of this SearchMonitoredResourceAssociationsDetails.
        :type destination_resource_id: str

        :param destination_resource_name:
            The value to assign to the destination_resource_name property of this SearchMonitoredResourceAssociationsDetails.
        :type destination_resource_name: str

        :param destination_resource_type:
            The value to assign to the destination_resource_type property of this SearchMonitoredResourceAssociationsDetails.
        :type destination_resource_type: str

        :param association_type:
            The value to assign to the association_type property of this SearchMonitoredResourceAssociationsDetails.
        :type association_type: str

        :param sort_by:
            The value to assign to the sort_by property of this SearchMonitoredResourceAssociationsDetails.
            Allowed values for this property are: "TIME_CREATED", "ASSOC_TYPE"
        :type sort_by: str

        :param sort_order:
            The value to assign to the sort_order property of this SearchMonitoredResourceAssociationsDetails.
            Allowed values for this property are: "ASC", "DESC"
        :type sort_order: str

        """
        self.swagger_types = {
            'compartment_id': 'str',
            'source_resource_id': 'str',
            'source_resource_name': 'str',
            'source_resource_type': 'str',
            'destination_resource_id': 'str',
            'destination_resource_name': 'str',
            'destination_resource_type': 'str',
            'association_type': 'str',
            'sort_by': 'str',
            'sort_order': 'str'
        }

        self.attribute_map = {
            'compartment_id': 'compartmentId',
            'source_resource_id': 'sourceResourceId',
            'source_resource_name': 'sourceResourceName',
            'source_resource_type': 'sourceResourceType',
            'destination_resource_id': 'destinationResourceId',
            'destination_resource_name': 'destinationResourceName',
            'destination_resource_type': 'destinationResourceType',
            'association_type': 'associationType',
            'sort_by': 'sortBy',
            'sort_order': 'sortOrder'
        }

        self._compartment_id = None
        self._source_resource_id = None
        self._source_resource_name = None
        self._source_resource_type = None
        self._destination_resource_id = None
        self._destination_resource_name = None
        self._destination_resource_type = None
        self._association_type = None
        self._sort_by = None
        self._sort_order = None

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this SearchMonitoredResourceAssociationsDetails.
        Compartment Identifier `OCID`__

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The compartment_id of this SearchMonitoredResourceAssociationsDetails.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this SearchMonitoredResourceAssociationsDetails.
        Compartment Identifier `OCID`__

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param compartment_id: The compartment_id of this SearchMonitoredResourceAssociationsDetails.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def source_resource_id(self):
        """
        Gets the source_resource_id of this SearchMonitoredResourceAssociationsDetails.
        Source Monitored Resource Identifier `OCID`__

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The source_resource_id of this SearchMonitoredResourceAssociationsDetails.
        :rtype: str
        """
        return self._source_resource_id

    @source_resource_id.setter
    def source_resource_id(self, source_resource_id):
        """
        Sets the source_resource_id of this SearchMonitoredResourceAssociationsDetails.
        Source Monitored Resource Identifier `OCID`__

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param source_resource_id: The source_resource_id of this SearchMonitoredResourceAssociationsDetails.
        :type: str
        """
        self._source_resource_id = source_resource_id

    @property
    def source_resource_name(self):
        """
        Gets the source_resource_name of this SearchMonitoredResourceAssociationsDetails.
        Source Monitored Resource Name


        :return: The source_resource_name of this SearchMonitoredResourceAssociationsDetails.
        :rtype: str
        """
        return self._source_resource_name

    @source_resource_name.setter
    def source_resource_name(self, source_resource_name):
        """
        Sets the source_resource_name of this SearchMonitoredResourceAssociationsDetails.
        Source Monitored Resource Name


        :param source_resource_name: The source_resource_name of this SearchMonitoredResourceAssociationsDetails.
        :type: str
        """
        self._source_resource_name = source_resource_name

    @property
    def source_resource_type(self):
        """
        Gets the source_resource_type of this SearchMonitoredResourceAssociationsDetails.
        Source Monitored Resource Type


        :return: The source_resource_type of this SearchMonitoredResourceAssociationsDetails.
        :rtype: str
        """
        return self._source_resource_type

    @source_resource_type.setter
    def source_resource_type(self, source_resource_type):
        """
        Sets the source_resource_type of this SearchMonitoredResourceAssociationsDetails.
        Source Monitored Resource Type


        :param source_resource_type: The source_resource_type of this SearchMonitoredResourceAssociationsDetails.
        :type: str
        """
        self._source_resource_type = source_resource_type

    @property
    def destination_resource_id(self):
        """
        Gets the destination_resource_id of this SearchMonitoredResourceAssociationsDetails.
        Destination Monitored Resource Identifier `OCID`__

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The destination_resource_id of this SearchMonitoredResourceAssociationsDetails.
        :rtype: str
        """
        return self._destination_resource_id

    @destination_resource_id.setter
    def destination_resource_id(self, destination_resource_id):
        """
        Sets the destination_resource_id of this SearchMonitoredResourceAssociationsDetails.
        Destination Monitored Resource Identifier `OCID`__

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param destination_resource_id: The destination_resource_id of this SearchMonitoredResourceAssociationsDetails.
        :type: str
        """
        self._destination_resource_id = destination_resource_id

    @property
    def destination_resource_name(self):
        """
        Gets the destination_resource_name of this SearchMonitoredResourceAssociationsDetails.
        Source Monitored Resource Name


        :return: The destination_resource_name of this SearchMonitoredResourceAssociationsDetails.
        :rtype: str
        """
        return self._destination_resource_name

    @destination_resource_name.setter
    def destination_resource_name(self, destination_resource_name):
        """
        Sets the destination_resource_name of this SearchMonitoredResourceAssociationsDetails.
        Source Monitored Resource Name


        :param destination_resource_name: The destination_resource_name of this SearchMonitoredResourceAssociationsDetails.
        :type: str
        """
        self._destination_resource_name = destination_resource_name

    @property
    def destination_resource_type(self):
        """
        Gets the destination_resource_type of this SearchMonitoredResourceAssociationsDetails.
        Source Monitored Resource Type


        :return: The destination_resource_type of this SearchMonitoredResourceAssociationsDetails.
        :rtype: str
        """
        return self._destination_resource_type

    @destination_resource_type.setter
    def destination_resource_type(self, destination_resource_type):
        """
        Sets the destination_resource_type of this SearchMonitoredResourceAssociationsDetails.
        Source Monitored Resource Type


        :param destination_resource_type: The destination_resource_type of this SearchMonitoredResourceAssociationsDetails.
        :type: str
        """
        self._destination_resource_type = destination_resource_type

    @property
    def association_type(self):
        """
        Gets the association_type of this SearchMonitoredResourceAssociationsDetails.
        Association type to be created between source and destination resources


        :return: The association_type of this SearchMonitoredResourceAssociationsDetails.
        :rtype: str
        """
        return self._association_type

    @association_type.setter
    def association_type(self, association_type):
        """
        Sets the association_type of this SearchMonitoredResourceAssociationsDetails.
        Association type to be created between source and destination resources


        :param association_type: The association_type of this SearchMonitoredResourceAssociationsDetails.
        :type: str
        """
        self._association_type = association_type

    @property
    def sort_by(self):
        """
        Gets the sort_by of this SearchMonitoredResourceAssociationsDetails.
        The field to sort by. Only one sort order may be provided.
        Default order for timeCreated is descending. Default order for assocType is descending.

        Allowed values for this property are: "TIME_CREATED", "ASSOC_TYPE"


        :return: The sort_by of this SearchMonitoredResourceAssociationsDetails.
        :rtype: str
        """
        return self._sort_by

    @sort_by.setter
    def sort_by(self, sort_by):
        """
        Sets the sort_by of this SearchMonitoredResourceAssociationsDetails.
        The field to sort by. Only one sort order may be provided.
        Default order for timeCreated is descending. Default order for assocType is descending.


        :param sort_by: The sort_by of this SearchMonitoredResourceAssociationsDetails.
        :type: str
        """
        allowed_values = ["TIME_CREATED", "ASSOC_TYPE"]
        if not value_allowed_none_or_none_sentinel(sort_by, allowed_values):
            raise ValueError(
                "Invalid value for `sort_by`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._sort_by = sort_by

    @property
    def sort_order(self):
        """
        Gets the sort_order of this SearchMonitoredResourceAssociationsDetails.
        The sort order to use, either 'ASC' or 'DESC'.

        Allowed values for this property are: "ASC", "DESC"


        :return: The sort_order of this SearchMonitoredResourceAssociationsDetails.
        :rtype: str
        """
        return self._sort_order

    @sort_order.setter
    def sort_order(self, sort_order):
        """
        Sets the sort_order of this SearchMonitoredResourceAssociationsDetails.
        The sort order to use, either 'ASC' or 'DESC'.


        :param sort_order: The sort_order of this SearchMonitoredResourceAssociationsDetails.
        :type: str
        """
        allowed_values = ["ASC", "DESC"]
        if not value_allowed_none_or_none_sentinel(sort_order, allowed_values):
            raise ValueError(
                "Invalid value for `sort_order`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._sort_order = sort_order

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class MetricStatisticsDefinition(object):
    """
    The metric statistics values with dimension details.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new MetricStatisticsDefinition object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param min:
            The value to assign to the min property of this MetricStatisticsDefinition.
        :type min: float

        :param max:
            The value to assign to the max property of this MetricStatisticsDefinition.
        :type max: float

        :param median:
            The value to assign to the median property of this MetricStatisticsDefinition.
        :type median: float

        :param lower_quartile:
            The value to assign to the lower_quartile property of this MetricStatisticsDefinition.
        :type lower_quartile: float

        :param upper_quartile:
            The value to assign to the upper_quartile property of this MetricStatisticsDefinition.
        :type upper_quartile: float

        :param unit:
            The value to assign to the unit property of this MetricStatisticsDefinition.
        :type unit: str

        :param dimensions:
            The value to assign to the dimensions property of this MetricStatisticsDefinition.
        :type dimensions: list[oci.database_management.models.MetricDimensionDefinition]

        """
        self.swagger_types = {
            'min': 'float',
            'max': 'float',
            'median': 'float',
            'lower_quartile': 'float',
            'upper_quartile': 'float',
            'unit': 'str',
            'dimensions': 'list[MetricDimensionDefinition]'
        }

        self.attribute_map = {
            'min': 'min',
            'max': 'max',
            'median': 'median',
            'lower_quartile': 'lowerQuartile',
            'upper_quartile': 'upperQuartile',
            'unit': 'unit',
            'dimensions': 'dimensions'
        }

        self._min = None
        self._max = None
        self._median = None
        self._lower_quartile = None
        self._upper_quartile = None
        self._unit = None
        self._dimensions = None

    @property
    def min(self):
        """
        Gets the min of this MetricStatisticsDefinition.
        The minimum value of the metric.


        :return: The min of this MetricStatisticsDefinition.
        :rtype: float
        """
        return self._min

    @min.setter
    def min(self, min):
        """
        Sets the min of this MetricStatisticsDefinition.
        The minimum value of the metric.


        :param min: The min of this MetricStatisticsDefinition.
        :type: float
        """
        self._min = min

    @property
    def max(self):
        """
        Gets the max of this MetricStatisticsDefinition.
        The maximum value of the metric.


        :return: The max of this MetricStatisticsDefinition.
        :rtype: float
        """
        return self._max

    @max.setter
    def max(self, max):
        """
        Sets the max of this MetricStatisticsDefinition.
        The maximum value of the metric.


        :param max: The max of this MetricStatisticsDefinition.
        :type: float
        """
        self._max = max

    @property
    def median(self):
        """
        Gets the median of this MetricStatisticsDefinition.
        The median value of the metric.


        :return: The median of this MetricStatisticsDefinition.
        :rtype: float
        """
        return self._median

    @median.setter
    def median(self, median):
        """
        Sets the median of this MetricStatisticsDefinition.
        The median value of the metric.


        :param median: The median of this MetricStatisticsDefinition.
        :type: float
        """
        self._median = median

    @property
    def lower_quartile(self):
        """
        Gets the lower_quartile of this MetricStatisticsDefinition.
        The first quartile value of the metric.


        :return: The lower_quartile of this MetricStatisticsDefinition.
        :rtype: float
        """
        return self._lower_quartile

    @lower_quartile.setter
    def lower_quartile(self, lower_quartile):
        """
        Sets the lower_quartile of this MetricStatisticsDefinition.
        The first quartile value of the metric.


        :param lower_quartile: The lower_quartile of this MetricStatisticsDefinition.
        :type: float
        """
        self._lower_quartile = lower_quartile

    @property
    def upper_quartile(self):
        """
        Gets the upper_quartile of this MetricStatisticsDefinition.
        The third quartile value of the metric.


        :return: The upper_quartile of this MetricStatisticsDefinition.
        :rtype: float
        """
        return self._upper_quartile

    @upper_quartile.setter
    def upper_quartile(self, upper_quartile):
        """
        Sets the upper_quartile of this MetricStatisticsDefinition.
        The third quartile value of the metric.


        :param upper_quartile: The upper_quartile of this MetricStatisticsDefinition.
        :type: float
        """
        self._upper_quartile = upper_quartile

    @property
    def unit(self):
        """
        Gets the unit of this MetricStatisticsDefinition.
        The unit of the metric value.


        :return: The unit of this MetricStatisticsDefinition.
        :rtype: str
        """
        return self._unit

    @unit.setter
    def unit(self, unit):
        """
        Sets the unit of this MetricStatisticsDefinition.
        The unit of the metric value.


        :param unit: The unit of this MetricStatisticsDefinition.
        :type: str
        """
        self._unit = unit

    @property
    def dimensions(self):
        """
        Gets the dimensions of this MetricStatisticsDefinition.
        The dimensions of the metric.


        :return: The dimensions of this MetricStatisticsDefinition.
        :rtype: list[oci.database_management.models.MetricDimensionDefinition]
        """
        return self._dimensions

    @dimensions.setter
    def dimensions(self, dimensions):
        """
        Sets the dimensions of this MetricStatisticsDefinition.
        The dimensions of the metric.


        :param dimensions: The dimensions of this MetricStatisticsDefinition.
        :type: list[oci.database_management.models.MetricDimensionDefinition]
        """
        self._dimensions = dimensions

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class Pattern(object):
    """
    A pattern is a data selector or filter which can provide a singular,
    logical entity view aggregating multiple physical data artifacts for ease of use.
    """

    #: A constant which can be used with the lifecycle_state property of a Pattern.
    #: This constant has a value of "CREATING"
    LIFECYCLE_STATE_CREATING = "CREATING"

    #: A constant which can be used with the lifecycle_state property of a Pattern.
    #: This constant has a value of "ACTIVE"
    LIFECYCLE_STATE_ACTIVE = "ACTIVE"

    #: A constant which can be used with the lifecycle_state property of a Pattern.
    #: This constant has a value of "INACTIVE"
    LIFECYCLE_STATE_INACTIVE = "INACTIVE"

    #: A constant which can be used with the lifecycle_state property of a Pattern.
    #: This constant has a value of "UPDATING"
    LIFECYCLE_STATE_UPDATING = "UPDATING"

    #: A constant which can be used with the lifecycle_state property of a Pattern.
    #: This constant has a value of "DELETING"
    LIFECYCLE_STATE_DELETING = "DELETING"

    #: A constant which can be used with the lifecycle_state property of a Pattern.
    #: This constant has a value of "DELETED"
    LIFECYCLE_STATE_DELETED = "DELETED"

    #: A constant which can be used with the lifecycle_state property of a Pattern.
    #: This constant has a value of "FAILED"
    LIFECYCLE_STATE_FAILED = "FAILED"

    #: A constant which can be used with the lifecycle_state property of a Pattern.
    #: This constant has a value of "MOVING"
    LIFECYCLE_STATE_MOVING = "MOVING"

    def __init__(self, **kwargs):
        """
        Initializes a new Pattern object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param key:
            The value to assign to the key property of this Pattern.
        :type key: str

        :param display_name:
            The value to assign to the display_name property of this Pattern.
        :type display_name: str

        :param description:
            The value to assign to the description property of this Pattern.
        :type description: str

        :param catalog_id:
            The value to assign to the catalog_id property of this Pattern.
        :type catalog_id: str

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this Pattern.
            Allowed values for this property are: "CREATING", "ACTIVE", "INACTIVE", "UPDATING", "DELETING", "DELETED", "FAILED", "MOVING", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param time_created:
            The value to assign to the time_created property of this Pattern.
        :type time_created: datetime

        :param time_updated:
            The value to assign to the time_updated property of this Pattern.
        :type time_updated: datetime

        :param created_by_id:
            The value to assign to the created_by_id property of this Pattern.
        :type created_by_id: str

        :param updated_by_id:
            The value to assign to the updated_by_id property of this Pattern.
        :type updated_by_id: str

        :param expression:
            The value to assign to the expression property of this Pattern.
        :type expression: str

        :param file_path_prefix:
            The value to assign to the file_path_prefix property of this Pattern.
        :type file_path_prefix: str

        :param check_file_path_list:
            The value to assign to the check_file_path_list property of this Pattern.
        :type check_file_path_list: list[str]

        :param is_enable_check_failure_limit:
            The value to assign to the is_enable_check_failure_limit property of this Pattern.
        :type is_enable_check_failure_limit: bool

        :param check_failure_limit:
            The value to assign to the check_failure_limit property of this Pattern.
        :type check_failure_limit: int

        :param properties:
            The value to assign to the properties property of this Pattern.
        :type properties: dict(str, dict(str, str))

        """
        self.swagger_types = {
            'key': 'str',
            'display_name': 'str',
            'description': 'str',
            'catalog_id': 'str',
            'lifecycle_state': 'str',
            'time_created': 'datetime',
            'time_updated': 'datetime',
            'created_by_id': 'str',
            'updated_by_id': 'str',
            'expression': 'str',
            'file_path_prefix': 'str',
            'check_file_path_list': 'list[str]',
            'is_enable_check_failure_limit': 'bool',
            'check_failure_limit': 'int',
            'properties': 'dict(str, dict(str, str))'
        }

        self.attribute_map = {
            'key': 'key',
            'display_name': 'displayName',
            'description': 'description',
            'catalog_id': 'catalogId',
            'lifecycle_state': 'lifecycleState',
            'time_created': 'timeCreated',
            'time_updated': 'timeUpdated',
            'created_by_id': 'createdById',
            'updated_by_id': 'updatedById',
            'expression': 'expression',
            'file_path_prefix': 'filePathPrefix',
            'check_file_path_list': 'checkFilePathList',
            'is_enable_check_failure_limit': 'isEnableCheckFailureLimit',
            'check_failure_limit': 'checkFailureLimit',
            'properties': 'properties'
        }

        self._key = None
        self._display_name = None
        self._description = None
        self._catalog_id = None
        self._lifecycle_state = None
        self._time_created = None
        self._time_updated = None
        self._created_by_id = None
        self._updated_by_id = None
        self._expression = None
        self._file_path_prefix = None
        self._check_file_path_list = None
        self._is_enable_check_failure_limit = None
        self._check_failure_limit = None
        self._properties = None

    @property
    def key(self):
        """
        **[Required]** Gets the key of this Pattern.
        Unique pattern key that is immutable.


        :return: The key of this Pattern.
        :rtype: str
        """
        return self._key

    @key.setter
    def key(self, key):
        """
        Sets the key of this Pattern.
        Unique pattern key that is immutable.


        :param key: The key of this Pattern.
        :type: str
        """
        self._key = key

    @property
    def display_name(self):
        """
        Gets the display_name of this Pattern.
        A user-friendly display name. Does not have to be unique, and it's changeable.
        Avoid entering confidential information.


        :return: The display_name of this Pattern.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this Pattern.
        A user-friendly display name. Does not have to be unique, and it's changeable.
        Avoid entering confidential information.


        :param display_name: The display_name of this Pattern.
        :type: str
        """
        self._display_name = display_name

    @property
    def description(self):
        """
        Gets the description of this Pattern.
        Detailed description of the pattern.


        :return: The description of this Pattern.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this Pattern.
        Detailed description of the pattern.


        :param description: The description of this Pattern.
        :type: str
        """
        self._description = description

    @property
    def catalog_id(self):
        """
        Gets the catalog_id of this Pattern.
        The data catalog's OCID.


        :return: The catalog_id of this Pattern.
        :rtype: str
        """
        return self._catalog_id

    @catalog_id.setter
    def catalog_id(self, catalog_id):
        """
        Sets the catalog_id of this Pattern.
        The data catalog's OCID.


        :param catalog_id: The catalog_id of this Pattern.
        :type: str
        """
        self._catalog_id = catalog_id

    @property
    def lifecycle_state(self):
        """
        Gets the lifecycle_state of this Pattern.
        The current state of the pattern.

        Allowed values for this property are: "CREATING", "ACTIVE", "INACTIVE", "UPDATING", "DELETING", "DELETED", "FAILED", "MOVING", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this Pattern.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this Pattern.
        The current state of the pattern.


        :param lifecycle_state: The lifecycle_state of this Pattern.
        :type: str
        """
        allowed_values = ["CREATING", "ACTIVE", "INACTIVE", "UPDATING", "DELETING", "DELETED", "FAILED", "MOVING"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    @property
    def time_created(self):
        """
        Gets the time_created of this Pattern.
        The date and time the pattern was created, in the format defined by `RFC3339`__.
        Example: `2019-03-25T21:10:29.600Z`

        __ https://tools.ietf.org/html/rfc3339


        :return: The time_created of this Pattern.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this Pattern.
        The date and time the pattern was created, in the format defined by `RFC3339`__.
        Example: `2019-03-25T21:10:29.600Z`

        __ https://tools.ietf.org/html/rfc3339


        :param time_created: The time_created of this Pattern.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def time_updated(self):
        """
        Gets the time_updated of this Pattern.
        The last time that any change was made to the pattern. An `RFC3339`__ formatted datetime string.

        __ https://tools.ietf.org/html/rfc3339


        :return: The time_updated of this Pattern.
        :rtype: datetime
        """
        return self._time_updated

    @time_updated.setter
    def time_updated(self, time_updated):
        """
        Sets the time_updated of this Pattern.
        The last time that any change was made to the pattern. An `RFC3339`__ formatted datetime string.

        __ https://tools.ietf.org/html/rfc3339


        :param time_updated: The time_updated of this Pattern.
        :type: datetime
        """
        self._time_updated = time_updated

    @property
    def created_by_id(self):
        """
        Gets the created_by_id of this Pattern.
        OCID of the user who created the pattern.


        :return: The created_by_id of this Pattern.
        :rtype: str
        """
        return self._created_by_id

    @created_by_id.setter
    def created_by_id(self, created_by_id):
        """
        Sets the created_by_id of this Pattern.
        OCID of the user who created the pattern.


        :param created_by_id: The created_by_id of this Pattern.
        :type: str
        """
        self._created_by_id = created_by_id

    @property
    def updated_by_id(self):
        """
        Gets the updated_by_id of this Pattern.
        OCID of the user who last modified the pattern.


        :return: The updated_by_id of this Pattern.
        :rtype: str
        """
        return self._updated_by_id

    @updated_by_id.setter
    def updated_by_id(self, updated_by_id):
        """
        Sets the updated_by_id of this Pattern.
        OCID of the user who last modified the pattern.


        :param updated_by_id: The updated_by_id of this Pattern.
        :type: str
        """
        self._updated_by_id = updated_by_id

    @property
    def expression(self):
        """
        Gets the expression of this Pattern.
        Input string which drives the selection process, allowing for fine-grained control using qualifiers.
        Refer to the user documentation for details of the format and examples. A pattern cannot include both
        a prefix and an expression.


        :return: The expression of this Pattern.
        :rtype: str
        """
        return self._expression

    @expression.setter
    def expression(self, expression):
        """
        Sets the expression of this Pattern.
        Input string which drives the selection process, allowing for fine-grained control using qualifiers.
        Refer to the user documentation for details of the format and examples. A pattern cannot include both
        a prefix and an expression.


        :param expression: The expression of this Pattern.
        :type: str
        """
        self._expression = expression

    @property
    def file_path_prefix(self):
        """
        Gets the file_path_prefix of this Pattern.
        Input string which drives the selection process.
        Refer to the user documentation for details of the format and examples. A pattern cannot include both
        a prefix and an expression.


        :return: The file_path_prefix of this Pattern.
        :rtype: str
        """
        return self._file_path_prefix

    @file_path_prefix.setter
    def file_path_prefix(self, file_path_prefix):
        """
        Sets the file_path_prefix of this Pattern.
        Input string which drives the selection process.
        Refer to the user documentation for details of the format and examples. A pattern cannot include both
        a prefix and an expression.


        :param file_path_prefix: The file_path_prefix of this Pattern.
        :type: str
        """
        self._file_path_prefix = file_path_prefix

    @property
    def check_file_path_list(self):
        """
        Gets the check_file_path_list of this Pattern.
        List of file paths against which the pattern can be tried, as a check. This documents, for reference
        purposes, some example objects a pattern is meant to work with. If isEnableCheckFailureLimit is set to true,
        this will be run as a validation during the request, such that if the check fails the request fails. If
        isEnableCheckFailureLimit instead is set to (the default) false, a pattern will still be created or updated even
        if the check fails, with a lifecycleState of FAILED.


        :return: The check_file_path_list of this Pattern.
        :rtype: list[str]
        """
        return self._check_file_path_list

    @check_file_path_list.setter
    def check_file_path_list(self, check_file_path_list):
        """
        Sets the check_file_path_list of this Pattern.
        List of file paths against which the pattern can be tried, as a check. This documents, for reference
        purposes, some example objects a pattern is meant to work with. If isEnableCheckFailureLimit is set to true,
        this will be run as a validation during the request, such that if the check fails the request fails. If
        isEnableCheckFailureLimit instead is set to (the default) false, a pattern will still be created or updated even
        if the check fails, with a lifecycleState of FAILED.


        :param check_file_path_list: The check_file_path_list of this Pattern.
        :type: list[str]
        """
        self._check_file_path_list = check_file_path_list

    @property
    def is_enable_check_failure_limit(self):
        """
        Gets the is_enable_check_failure_limit of this Pattern.
        Indicates whether the pattern check, against the checkFilePathList, will fail the request if the count of
        UNMATCHED files is above the checkFailureLimit.


        :return: The is_enable_check_failure_limit of this Pattern.
        :rtype: bool
        """
        return self._is_enable_check_failure_limit

    @is_enable_check_failure_limit.setter
    def is_enable_check_failure_limit(self, is_enable_check_failure_limit):
        """
        Sets the is_enable_check_failure_limit of this Pattern.
        Indicates whether the pattern check, against the checkFilePathList, will fail the request if the count of
        UNMATCHED files is above the checkFailureLimit.


        :param is_enable_check_failure_limit: The is_enable_check_failure_limit of this Pattern.
        :type: bool
        """
        self._is_enable_check_failure_limit = is_enable_check_failure_limit

    @property
    def check_failure_limit(self):
        """
        Gets the check_failure_limit of this Pattern.
        The maximum number of UNMATCHED files, in checkFilePathList, above which the check fails. Optional, if
        checkFilePathList is provided - but if isEnableCheckFailureLimit is set to true it is required.


        :return: The check_failure_limit of this Pattern.
        :rtype: int
        """
        return self._check_failure_limit

    @check_failure_limit.setter
    def check_failure_limit(self, check_failure_limit):
        """
        Sets the check_failure_limit of this Pattern.
        The maximum number of UNMATCHED files, in checkFilePathList, above which the check fails. Optional, if
        checkFilePathList is provided - but if isEnableCheckFailureLimit is set to true it is required.


        :param check_failure_limit: The check_failure_limit of this Pattern.
        :type: int
        """
        self._check_failure_limit = check_failure_limit

    @property
    def properties(self):
        """
        Gets the properties of this Pattern.
        A map of maps that contains the properties which are specific to the pattern type. Each pattern type
        definition defines it's set of required and optional properties.
        Example: `{\"properties\": { \"default\": { \"tbd\"}}}`


        :return: The properties of this Pattern.
        :rtype: dict(str, dict(str, str))
        """
        return self._properties

    @properties.setter
    def properties(self, properties):
        """
        Sets the properties of this Pattern.
        A map of maps that contains the properties which are specific to the pattern type. Each pattern type
        definition defines it's set of required and optional properties.
        Example: `{\"properties\": { \"default\": { \"tbd\"}}}`


        :param properties: The properties of this Pattern.
        :type: dict(str, dict(str, str))
        """
        self._properties = properties

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class UpdateSensitiveColumnDetails(object):
    """
    Details to update a sensitive column in a sensitive data model.
    """

    #: A constant which can be used with the status property of a UpdateSensitiveColumnDetails.
    #: This constant has a value of "VALID"
    STATUS_VALID = "VALID"

    #: A constant which can be used with the status property of a UpdateSensitiveColumnDetails.
    #: This constant has a value of "INVALID"
    STATUS_INVALID = "INVALID"

    #: A constant which can be used with the relation_type property of a UpdateSensitiveColumnDetails.
    #: This constant has a value of "NONE"
    RELATION_TYPE_NONE = "NONE"

    #: A constant which can be used with the relation_type property of a UpdateSensitiveColumnDetails.
    #: This constant has a value of "APP_DEFINED"
    RELATION_TYPE_APP_DEFINED = "APP_DEFINED"

    #: A constant which can be used with the relation_type property of a UpdateSensitiveColumnDetails.
    #: This constant has a value of "DB_DEFINED"
    RELATION_TYPE_DB_DEFINED = "DB_DEFINED"

    def __init__(self, **kwargs):
        """
        Initializes a new UpdateSensitiveColumnDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param data_type:
            The value to assign to the data_type property of this UpdateSensitiveColumnDetails.
        :type data_type: str

        :param status:
            The value to assign to the status property of this UpdateSensitiveColumnDetails.
            Allowed values for this property are: "VALID", "INVALID"
        :type status: str

        :param sensitive_type_id:
            The value to assign to the sensitive_type_id property of this UpdateSensitiveColumnDetails.
        :type sensitive_type_id: str

        :param parent_column_keys:
            The value to assign to the parent_column_keys property of this UpdateSensitiveColumnDetails.
        :type parent_column_keys: list[str]

        :param relation_type:
            The value to assign to the relation_type property of this UpdateSensitiveColumnDetails.
            Allowed values for this property are: "NONE", "APP_DEFINED", "DB_DEFINED"
        :type relation_type: str

        :param app_defined_child_column_keys:
            The value to assign to the app_defined_child_column_keys property of this UpdateSensitiveColumnDetails.
        :type app_defined_child_column_keys: list[str]

        :param db_defined_child_column_keys:
            The value to assign to the db_defined_child_column_keys property of this UpdateSensitiveColumnDetails.
        :type db_defined_child_column_keys: list[str]

        """
        self.swagger_types = {
            'data_type': 'str',
            'status': 'str',
            'sensitive_type_id': 'str',
            'parent_column_keys': 'list[str]',
            'relation_type': 'str',
            'app_defined_child_column_keys': 'list[str]',
            'db_defined_child_column_keys': 'list[str]'
        }

        self.attribute_map = {
            'data_type': 'dataType',
            'status': 'status',
            'sensitive_type_id': 'sensitiveTypeId',
            'parent_column_keys': 'parentColumnKeys',
            'relation_type': 'relationType',
            'app_defined_child_column_keys': 'appDefinedChildColumnKeys',
            'db_defined_child_column_keys': 'dbDefinedChildColumnKeys'
        }

        self._data_type = None
        self._status = None
        self._sensitive_type_id = None
        self._parent_column_keys = None
        self._relation_type = None
        self._app_defined_child_column_keys = None
        self._db_defined_child_column_keys = None

    @property
    def data_type(self):
        """
        Gets the data_type of this UpdateSensitiveColumnDetails.
        The data type of the sensitive column.


        :return: The data_type of this UpdateSensitiveColumnDetails.
        :rtype: str
        """
        return self._data_type

    @data_type.setter
    def data_type(self, data_type):
        """
        Sets the data_type of this UpdateSensitiveColumnDetails.
        The data type of the sensitive column.


        :param data_type: The data_type of this UpdateSensitiveColumnDetails.
        :type: str
        """
        self._data_type = data_type

    @property
    def status(self):
        """
        Gets the status of this UpdateSensitiveColumnDetails.
        The status of the sensitive column. VALID means the column is considered sensitive. INVALID means the column
        is not considered sensitive. Tracking invalid columns in a sensitive data model helps ensure that an incremental
        data discovery job does not identify these columns as sensitive.

        Allowed values for this property are: "VALID", "INVALID"


        :return: The status of this UpdateSensitiveColumnDetails.
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """
        Sets the status of this UpdateSensitiveColumnDetails.
        The status of the sensitive column. VALID means the column is considered sensitive. INVALID means the column
        is not considered sensitive. Tracking invalid columns in a sensitive data model helps ensure that an incremental
        data discovery job does not identify these columns as sensitive.


        :param status: The status of this UpdateSensitiveColumnDetails.
        :type: str
        """
        allowed_values = ["VALID", "INVALID"]
        if not value_allowed_none_or_none_sentinel(status, allowed_values):
            raise ValueError(
                "Invalid value for `status`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._status = status

    @property
    def sensitive_type_id(self):
        """
        Gets the sensitive_type_id of this UpdateSensitiveColumnDetails.
        The OCID of the sensitive type to be associated with the sensitive column.


        :return: The sensitive_type_id of this UpdateSensitiveColumnDetails.
        :rtype: str
        """
        return self._sensitive_type_id

    @sensitive_type_id.setter
    def sensitive_type_id(self, sensitive_type_id):
        """
        Sets the sensitive_type_id of this UpdateSensitiveColumnDetails.
        The OCID of the sensitive type to be associated with the sensitive column.


        :param sensitive_type_id: The sensitive_type_id of this UpdateSensitiveColumnDetails.
        :type: str
        """
        self._sensitive_type_id = sensitive_type_id

    @property
    def parent_column_keys(self):
        """
        Gets the parent_column_keys of this UpdateSensitiveColumnDetails.
        Unique keys identifying the columns that are parents of the sensitive column. At present, it accepts only one
        parent column key. This attribute can be used to establish relationship between columns in a sensitive data model.
        Note that the parent column must be added to the sensitive data model before its key can be specified here.
        If this attribute is provided, the appDefinedChildColumnKeys or dbDefinedChildColumnKeys attribute of the
        parent column is automatically updated to reflect the relationship.


        :return: The parent_column_keys of this UpdateSensitiveColumnDetails.
        :rtype: list[str]
        """
        return self._parent_column_keys

    @parent_column_keys.setter
    def parent_column_keys(self, parent_column_keys):
        """
        Sets the parent_column_keys of this UpdateSensitiveColumnDetails.
        Unique keys identifying the columns that are parents of the sensitive column. At present, it accepts only one
        parent column key. This attribute can be used to establish relationship between columns in a sensitive data model.
        Note that the parent column must be added to the sensitive data model before its key can be specified here.
        If this attribute is provided, the appDefinedChildColumnKeys or dbDefinedChildColumnKeys attribute of the
        parent column is automatically updated to reflect the relationship.


        :param parent_column_keys: The parent_column_keys of this UpdateSensitiveColumnDetails.
        :type: list[str]
        """
        self._parent_column_keys = parent_column_keys

    @property
    def relation_type(self):
        """
        Gets the relation_type of this UpdateSensitiveColumnDetails.
        The type of referential relationship the sensitive column has with its parent. NONE indicates that the sensitive
        column does not have a parent. DB_DEFINED indicates that the relationship is defined in the database dictionary.
        APP_DEFINED indicates that the relationship is defined at the application level and not in the database dictionary.

        Allowed values for this property are: "NONE", "APP_DEFINED", "DB_DEFINED"


        :return: The relation_type of this UpdateSensitiveColumnDetails.
        :rtype: str
        """
        return self._relation_type

    @relation_type.setter
    def relation_type(self, relation_type):
        """
        Sets the relation_type of this UpdateSensitiveColumnDetails.
        The type of referential relationship the sensitive column has with its parent. NONE indicates that the sensitive
        column does not have a parent. DB_DEFINED indicates that the relationship is defined in the database dictionary.
        APP_DEFINED indicates that the relationship is defined at the application level and not in the database dictionary.


        :param relation_type: The relation_type of this UpdateSensitiveColumnDetails.
        :type: str
        """
        allowed_values = ["NONE", "APP_DEFINED", "DB_DEFINED"]
        if not value_allowed_none_or_none_sentinel(relation_type, allowed_values):
            raise ValueError(
                "Invalid value for `relation_type`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._relation_type = relation_type

    @property
    def app_defined_child_column_keys(self):
        """
        Gets the app_defined_child_column_keys of this UpdateSensitiveColumnDetails.
        Unique keys identifying the columns that are application-level (non-dictionary) children of the sensitive column.
        This attribute can be used to establish relationship between columns in a sensitive data model. Note that the
        child columns must be added to the sensitive data model before their keys can be specified here. If this attribute
        is provided, the parentColumnKeys and relationType attributes of the child columns are automatically updated to reflect the relationship.


        :return: The app_defined_child_column_keys of this UpdateSensitiveColumnDetails.
        :rtype: list[str]
        """
        return self._app_defined_child_column_keys

    @app_defined_child_column_keys.setter
    def app_defined_child_column_keys(self, app_defined_child_column_keys):
        """
        Sets the app_defined_child_column_keys of this UpdateSensitiveColumnDetails.
        Unique keys identifying the columns that are application-level (non-dictionary) children of the sensitive column.
        This attribute can be used to establish relationship between columns in a sensitive data model. Note that the
        child columns must be added to the sensitive data model before their keys can be specified here. If this attribute
        is provided, the parentColumnKeys and relationType attributes of the child columns are automatically updated to reflect the relationship.


        :param app_defined_child_column_keys: The app_defined_child_column_keys of this UpdateSensitiveColumnDetails.
        :type: list[str]
        """
        self._app_defined_child_column_keys = app_defined_child_column_keys

    @property
    def db_defined_child_column_keys(self):
        """
        Gets the db_defined_child_column_keys of this UpdateSensitiveColumnDetails.
        Unique keys identifying the columns that are database-level (dictionary-defined) children of the sensitive column.
        This attribute can be used to establish relationship between columns in a sensitive data model. Note that the
        child columns must be added to the sensitive data model before their keys can be specified here. If this attribute
        is provided, the parentColumnKeys and relationType attributes of the child columns are automatically updated to reflect the relationship.


        :return: The db_defined_child_column_keys of this UpdateSensitiveColumnDetails.
        :rtype: list[str]
        """
        return self._db_defined_child_column_keys

    @db_defined_child_column_keys.setter
    def db_defined_child_column_keys(self, db_defined_child_column_keys):
        """
        Sets the db_defined_child_column_keys of this UpdateSensitiveColumnDetails.
        Unique keys identifying the columns that are database-level (dictionary-defined) children of the sensitive column.
        This attribute can be used to establish relationship between columns in a sensitive data model. Note that the
        child columns must be added to the sensitive data model before their keys can be specified here. If this attribute
        is provided, the parentColumnKeys and relationType attributes of the child columns are automatically updated to reflect the relationship.


        :param db_defined_child_column_keys: The db_defined_child_column_keys of this UpdateSensitiveColumnDetails.
        :type: list[str]
        """
        self._db_defined_child_column_keys = db_defined_child_column_keys

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .build_source import BuildSource
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class GithubBuildSource(BuildSource):
    """
    GitHub build source for Build stage.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new GithubBuildSource object with values from keyword arguments. The default value of the :py:attr:`~oci.devops.models.GithubBuildSource.connection_type` attribute
        of this class is ``GITHUB`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param name:
            The value to assign to the name property of this GithubBuildSource.
        :type name: str

        :param connection_type:
            The value to assign to the connection_type property of this GithubBuildSource.
            Allowed values for this property are: "GITHUB", "GITLAB", "BITBUCKET_CLOUD", "DEVOPS_CODE_REPOSITORY"
        :type connection_type: str

        :param repository_url:
            The value to assign to the repository_url property of this GithubBuildSource.
        :type repository_url: str

        :param branch:
            The value to assign to the branch property of this GithubBuildSource.
        :type branch: str

        :param connection_id:
            The value to assign to the connection_id property of this GithubBuildSource.
        :type connection_id: str

        """
        self.swagger_types = {
            'name': 'str',
            'connection_type': 'str',
            'repository_url': 'str',
            'branch': 'str',
            'connection_id': 'str'
        }

        self.attribute_map = {
            'name': 'name',
            'connection_type': 'connectionType',
            'repository_url': 'repositoryUrl',
            'branch': 'branch',
            'connection_id': 'connectionId'
        }

        self._name = None
        self._connection_type = None
        self._repository_url = None
        self._branch = None
        self._connection_id = None
        self._connection_type = 'GITHUB'

    @property
    def connection_id(self):
        """
        **[Required]** Gets the connection_id of this GithubBuildSource.
        Connection identifier pertinent to GitHub source provider.


        :return: The connection_id of this GithubBuildSource.
        :rtype: str
        """
        return self._connection_id

    @connection_id.setter
    def connection_id(self, connection_id):
        """
        Sets the connection_id of this GithubBuildSource.
        Connection identifier pertinent to GitHub source provider.


        :param connection_id: The connection_id of this GithubBuildSource.
        :type: str
        """
        self._connection_id = connection_id

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .web_app_acceleration_summary import WebAppAccelerationSummary
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class WebAppAccelerationLoadBalancerSummary(WebAppAccelerationSummary):
    """
    Summary of the WebAppAccelerationLoadBalancer.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new WebAppAccelerationLoadBalancerSummary object with values from keyword arguments. The default value of the :py:attr:`~oci.waa.models.WebAppAccelerationLoadBalancerSummary.backend_type` attribute
        of this class is ``LOAD_BALANCER`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this WebAppAccelerationLoadBalancerSummary.
        :type id: str

        :param display_name:
            The value to assign to the display_name property of this WebAppAccelerationLoadBalancerSummary.
        :type display_name: str

        :param compartment_id:
            The value to assign to the compartment_id property of this WebAppAccelerationLoadBalancerSummary.
        :type compartment_id: str

        :param backend_type:
            The value to assign to the backend_type property of this WebAppAccelerationLoadBalancerSummary.
            Allowed values for this property are: "LOAD_BALANCER"
        :type backend_type: str

        :param web_app_acceleration_policy_id:
            The value to assign to the web_app_acceleration_policy_id property of this WebAppAccelerationLoadBalancerSummary.
        :type web_app_acceleration_policy_id: str

        :param time_created:
            The value to assign to the time_created property of this WebAppAccelerationLoadBalancerSummary.
        :type time_created: datetime

        :param time_updated:
            The value to assign to the time_updated property of this WebAppAccelerationLoadBalancerSummary.
        :type time_updated: datetime

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this WebAppAccelerationLoadBalancerSummary.
        :type lifecycle_state: str

        :param lifecycle_details:
            The value to assign to the lifecycle_details property of this WebAppAccelerationLoadBalancerSummary.
        :type lifecycle_details: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this WebAppAccelerationLoadBalancerSummary.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this WebAppAccelerationLoadBalancerSummary.
        :type defined_tags: dict(str, dict(str, object))

        :param system_tags:
            The value to assign to the system_tags property of this WebAppAccelerationLoadBalancerSummary.
        :type system_tags: dict(str, dict(str, object))

        :param load_balancer_id:
            The value to assign to the load_balancer_id property of this WebAppAccelerationLoadBalancerSummary.
        :type load_balancer_id: str

        """
        self.swagger_types = {
            'id': 'str',
            'display_name': 'str',
            'compartment_id': 'str',
            'backend_type': 'str',
            'web_app_acceleration_policy_id': 'str',
            'time_created': 'datetime',
            'time_updated': 'datetime',
            'lifecycle_state': 'str',
            'lifecycle_details': 'str',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))',
            'system_tags': 'dict(str, dict(str, object))',
            'load_balancer_id': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'display_name': 'displayName',
            'compartment_id': 'compartmentId',
            'backend_type': 'backendType',
            'web_app_acceleration_policy_id': 'webAppAccelerationPolicyId',
            'time_created': 'timeCreated',
            'time_updated': 'timeUpdated',
            'lifecycle_state': 'lifecycleState',
            'lifecycle_details': 'lifecycleDetails',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags',
            'system_tags': 'systemTags',
            'load_balancer_id': 'loadBalancerId'
        }

        self._id = None
        self._display_name = None
        self._compartment_id = None
        self._backend_type = None
        self._web_app_acceleration_policy_id = None
        self._time_created = None
        self._time_updated = None
        self._lifecycle_state = None
        self._lifecycle_details = None
        self._freeform_tags = None
        self._defined_tags = None
        self._system_tags = None
        self._load_balancer_id = None
        self._backend_type = 'LOAD_BALANCER'

    @property
    def load_balancer_id(self):
        """
        **[Required]** Gets the load_balancer_id of this WebAppAccelerationLoadBalancerSummary.
        LoadBalancer `OCID`__ to which the WebAppAccelerationPolicy is attached to.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The load_balancer_id of this WebAppAccelerationLoadBalancerSummary.
        :rtype: str
        """
        return self._load_balancer_id

    @load_balancer_id.setter
    def load_balancer_id(self, load_balancer_id):
        """
        Sets the load_balancer_id of this WebAppAccelerationLoadBalancerSummary.
        LoadBalancer `OCID`__ to which the WebAppAccelerationPolicy is attached to.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param load_balancer_id: The load_balancer_id of this WebAppAccelerationLoadBalancerSummary.
        :type: str
        """
        self._load_balancer_id = load_balancer_id

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other
